<?php
/**
 * Header — Compartido por todas las páginas.
 * Hooks WP obligatorios incluidos (ver feedback_wordpress_sites.md).
 */
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo('charset'); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<link rel="preconnect" href="https://fonts.googleapis.com">
<link href="https://fonts.googleapis.com/css2?family=Bebas+Neue&family=Inter:wght@300;400;500;600;700;800;900&display=swap" rel="stylesheet">
<?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>

<nav class="nav" id="nav">
  <a href="<?php echo esc_url(home_url('/')); ?>" class="nav-logo">
    <img src="https://dimark.co/wp-content/themes/dimark/images/logoheader.png" alt="Dimark">
  </a>
  <div class="nav-links">
    <a href="#servicios">Servicios</a>
    <a href="#planes">Planes</a>
    <a href="#casos">Casos de éxito</a>
    <a href="https://dimark.co/somos-grupo-dimark/" target="_blank">Nosotros</a>
    <a href="https://dimark.co/contactenos/" target="_blank">Contacto</a>
  </div>
  <a href="https://api.whatsapp.com/send/?phone=573203920599&text=Hola%2C+quiero+m%C3%A1s+informaci%C3%B3n+sobre+Dimark" target="_blank" class="nav-btn">Hablar con experto</a>
</nav>
