<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit34f09cb5b1b6fe16179f501dbe335b80
{
    public static $prefixLengthsPsr4 = array (
        'E' =>
        array (
            'Elementor\\WPNotificationsPackage\\' => 33,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'Elementor\\WPNotificationsPackage\\' =>
        array (
            0 => __DIR__ . '/..' . '/elementor/wp-notifications-package/src',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit34f09cb5b1b6fe16179f501dbe335b80::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit34f09cb5b1b6fe16179f501dbe335b80::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInit34f09cb5b1b6fe16179f501dbe335b80::$classMap;

        }, null, ClassLoader::class);
    }
}
