<?php
/**
 * Template-part: certified
 */
?>
<section class="certified-sec" id="certificados">
  <div class="certified-grid">
    <div class="certified-inner">
      <div class="eyebrow"><span class="eyebrow-line"></span>Certificaciones oficiales</div>
      <h2 class="sec-title" style="margin-bottom:16px">Agencia certificada en<br>Google Ads y Meta Ads</h2>
      <p class="sec-sub" style="max-width:780px">Somos partners certificados de Google Ads y Meta Ads, lo que respalda nuestro conocimiento técnico y estratégico en la gestión de campañas publicitarias digitales.</p>
      <div class="certified-badges">
        <img src="https://dimark.co/wp-content/uploads/2026/01/WhatsApp-Image-2026-01-13-at-9.39.34-AM.jpeg" alt="Meta Partner" style="height:112px;width:auto;border-radius:8px;object-fit:contain;background:#fff;padding:6px">
        <a href="https://www.google.com/partners/agency?id=2597029018" target="_blank">
          <img src="https://www.gstatic.com/partners/badge/images/2025/PartnerBadgeClickable.svg" alt="Google Partner Badge" style="height:112px;width:auto"/>
        </a>
      </div>
    </div>
    <img class="certified-world" src="https://dimark.co/wp-content/uploads/2025/07/mapmundi.png" alt="Presencia mundial Dimark" loading="lazy">
  </div>
</section>
