<form role="search" method="get" class="search-form" action="<?php echo esc_url( home_url( '/' ) ) ?>">
    <input class="searchform-mid clearit" type="text" name="s" id="search-header" placeholder="<?=esc_attr_x( 'Puedes buscar lo que desees sobre hosting y los diferentes tipos servidores.', 'placeholder' )?>" value="<?=get_search_query()?>">
</form>