<?php
/**
 * Template-part: stats
 */
?>
<div class="stats">
  <div class="stat"><div class="stat-n"><span class="acc">+</span>10</div><div class="stat-l">Años de<br>experiencia</div></div>
  <div class="stat"><div class="stat-n"><span class="acc">+</span>200</div><div class="stat-l">Sitios web<br>creados</div></div>
  <div class="stat"><div class="stat-n"><span class="acc">+</span>500</div><div class="stat-l">Keywords en<br>primeros puestos</div></div>
  <div class="stat"><div class="stat-n" style="font-size:26px;letter-spacing:0">LATAM<span class="acc"> + </span>USA</div><div class="stat-l">Presencia<br>internacional</div></div>
  <div class="stat"><div class="stat-n" style="font-size:28px;color:var(--red)">AVI IA</div><div class="stat-l">Asistente propio<br>con inteligencia artificial</div></div>
</div>
