<?php
/**
 * Template-part: casos
 */
?>
<section class="sec sec-bg1" id="casos">
  <div style="max-width:640px;margin-bottom:40px">
    <div class="eyebrow"><span class="eyebrow-line"></span>Resultados reales</div>
    <h2 class="sec-title">Casos de éxito</h2>
    <p class="sec-sub">Empresas que apostaron por Dimark y transformaron su crecimiento digital.</p>
  </div>
  <div class="ctabs">
    <div class="ctab on" data-cat="web">🌐 Sitios web</div>
    <div class="ctab" data-cat="seo">📈 SEO</div>
    <div class="ctab" data-cat="google-ads">🔍 Google Ads</div>
    <div class="ctab" data-cat="meta-ads">📣 Meta Ads</div>
    <div class="ctab" data-cat="avi">🤖 AVI Asistente</div>
  </div>
  <div id="casosContent"></div>
</section>
