<?php return array(
    'root' => array(
        'name' => 'elementor/hello-theme',
        'pretty_version' => '3.4.x-dev',
        'version' => '3.4.9999999.9999999-dev',
        'reference' => 'f4e4ae4193ef7cd2e82d5552d3377ba9f3274235',
        'type' => 'library',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'elementor/hello-theme' => array(
            'pretty_version' => '3.4.x-dev',
            'version' => '3.4.9999999.9999999-dev',
            'reference' => 'f4e4ae4193ef7cd2e82d5552d3377ba9f3274235',
            'type' => 'library',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'elementor/wp-notifications-package' => array(
            'pretty_version' => '1.2.0',
            'version' => '1.2.0.0',
            'reference' => 'dd25ca9dd79402c3bb51fab112aa079702eb165e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../elementor/wp-notifications-package',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
