:root{
  --primary: rgb(36 36 36 / 1);
  --darkprimary: #151515;
  --secundary: rgb(193 0 24 / 1);
  --darksecundary: #960213;
  --gray:#cccccc;
  --gray-text:#6A6A6A;
}
main{
  overflow: hidden;
}

a{
  text-decoration: none;
}

.elementor-heading-title h1,
.elementor-heading-title h2,
.elementor-heading-title h3,
.elementor-heading-title h4,
.elementor-heading-title h5,
.elementor-heading-title h6
{
  font-family: "Work Sans", sans-serif !important;
}

button{
  font-family: "Montserrat", sans-serif;
  margin: 0;
  padding-top: 0;
  border: none;
  text-decoration: none;
}

/* NAV STYLES */
.nav{
  width: 300px;
}


.banner__icon {
  height: 64px;
  width: 64px;
  stroke: #fff;
}

.nav__link{
  color: #fff;
  text-decoration: none;
  padding: 15px 0;
  display: block;
  font-size: 20px;
}

.nav__link--inside{
  text-align: left;
}

.nav__link--inside:hover{
  background-color: var(--darksecundary);
}


.list{
  width: 100%;
  height: 100vh;
  display: flex;
  flex-direction: column;
  justify-content: center;
  padding: 0;
}


.list__item{
  width: 100%;
  text-align: center;
  list-style: none;
  overflow: hidden;
}


.list__show{
  width: 80%;
  margin-left: auto;
  border-left: 2px solid #ccc;
  list-style: none;
  transition: height .4s;
  height: 0;
}


.list__item--click{
  cursor: pointer;
}

.list__button{
  display: flex;
  align-items: center;
  gap: 1em;
  width: 70%;
  margin: 0 auto;
}

.arrow .list__arrow{
  transform: rotate(90deg);
}

.list__arrow{
  margin-left: auto;
  transition: transform .3s;
}
/* NAV STYLES */

.menu-popup{
  width: 100%;
  height: 100%;
  z-index: 100;
  display: flex;
  background-color: var(--darkprimary);
  justify-content: center;
  align-items: center;
}
.hidden{
  display: none;
}
.fixed{
  display: flex;
  position: fixed;
}

.popup-close{
  position: fixed;
  top: 20px;
  right: 20px;
  color: #fff;
  background-color: var(--secundary);
  font-size: 30px;
  height: 40px;
  width: 40px;
  z-index: 120;
  cursor: pointer;
}
.popup-close:hover{
  background-color: var(--darksecundary);
}

.menu-popup .left-container{
  width: 90%;
  height: 80%;
  z-index: 10;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}
.menu-popup .right-container{
  display: none;
}
.menu-popup .right-container .img{
  width: 200px;
  height: 200px;
  object-fit: contain;
}


.menu-popup .right-container .icons-wrapper{
  display: flex;
  gap: 20px;
}

.list-item{
  display: flex;
  flex-direction: column;
  margin: 40px 0px;
}
.list-item h3{
  color: #ffffffb6;
  font-size: 16px;
  font-weight: 400;
  margin-bottom: 20px;
}

.list-item p{
  color: #ffffff;
  font-size: 20px;
  font-weight: 700;
  font-family: "Montserrat", sans-serif;
}

@media (min-width:1000px) {

  .menu-popup .right-container{
    display: block;
    width: 20%;
    z-index: 10;
    height: 70%;
    border-left: 1px solid #ffffff6b;
    padding-left: 40px;
  }
  .menu-popup .left-container{
    width: 50%;
    height: 70%;
    z-index: 10;
    display: flex;
    flex-direction: column;
    justify-content: center;
    align-items: start;
  }
}


.fade-down{
  animation-name: fadedownover;
  animation-duration: 0.5s;
  animation-timing-function: ease-in-out;
}
.fade-up{
  animation-name: fadeupover;
  animation-duration: 0.5s;
  animation-timing-function: ease-in-out;
}


@keyframes fadedown {
  from{
    opacity: 0;
    transform: translateY(-100%);
  }
  to{
    opacity: 1;
    transform: translateY(0%);
  }
}

@keyframes fadedownover {
  from{
    opacity: 0;
    transform: translateY(-100%);
  }
  to{
   
    opacity: 1;
    transform: translateY(0%);
  }
}

@keyframes fadeupover {
  from{
    opacity: 1;
    transform: translateY(0%);
  }
  to{
   
    opacity: 1;
    transform: translateY(-100%);
  }
}


.hand-icon{
    width: 64px;
    height: 64px;
    stroke: #fff ;
    stroke-width: 1.5px;
}

.plus-icon{
    width: 24px;
    height: 24px;
    stroke: #fff;
    stroke-width: 1px;
}

.overlay-bg{
    position: absolute;
    inset: 0;
    width: 100%;
    height: 100%;
    background-color: transparent;
      background-image: linear-gradient(180deg, #00000091 0%, #000000 100%);
      opacity: 1;
  }
  .overlay-bg-red{
    position: absolute;
    inset: 0;
    transform: translateY(100%);
    width: 100%;
    height: 100%;
    background-color: transparent;
    background-image: linear-gradient(180deg, transparent 0%, var(--secundary) 100%);
    opacity: 1;
    transition: all .3s ease;
  }

.banner-section:hover .overlay-bg-red{
  transform: translateY(0%);
}


.banner-container{
    width: 100%;
    display: flex;
    flex-direction: column;
    background-color: var(--primary);
}

.banner-section{
    width: 100%;
    height: 400px;
    position: relative;
    display: flex;
    justify-content: center;
    align-items: end;
    padding-top: 80px;
    overflow: hidden;
}


.banner-section-content{
    display: flex;
    flex-direction: column;
    align-items: center;
    z-index: 10;
    padding-left: 30px;
    padding-right: 30px;
    padding-bottom: 85px;
}
.banner-section-content-icon{
    margin-bottom: 8px;
}

.banner-section-content-title{
    font-size: 40px;
    line-height: 38px;
    font-weight: 700;
    color: #fff;
    text-align: center;
    margin-bottom: 8px;
    margin-top: 8px;
}

.banner-section-content-description{
    font-size: 20px;
    line-height: 26px;
    font-weight: 300;
    color: #fff;
    text-align: center;
    margin-bottom: 32px;
}

.banner-section-content-button{
    display: flex;
    align-items: center;
    gap: 8px;
    width: fit-content;
    color: #fff;
    font-family: "Montserrat", sans-serif;
    font-weight: 700;
    padding: 14px 24px;
    transition: background-color .3s ease;
    background-color: transparent;
    border: solid 2px var(--secundary);
}
.banner-section-content-button:hover{
  cursor: pointer;
  background-color: var(--secundary);
  border: solid 2px #fff;
}

.banner-section-1{
    background-image: url("/wp-content/themes/dimark/images/banner1.jpg");
    background-position: center center;
    background-repeat: no-repeat;
    background-size: cover;
}

.banner-section-2{
    background-image: url("/wp-content/themes/dimark/images/banner2.jpg");
    background-position: center center;
    background-repeat: no-repeat;
    background-size: cover;
}
.banner-section-3{
    background-image: url("/wp-content/themes/dimark/images/banner3.jpg");
    background-position: center center;
    background-repeat: no-repeat;
    background-size: cover;
}
.banner-section-4{
    background-image: url("/wp-content/themes/dimark/images/banner4.jpg");
    background-position: center center;
    background-repeat: no-repeat;
    background-size: cover;
}
/* Banner Media */
@media (min-width:1000px) {

  .banner-container{
    display: flex;
    flex-direction: row;
  }
  .banner-section{
    width: 25%;
    height: 100vh;
    padding-top: 0px;
  }
}
/* Banner Media */
.header{
  z-index: 50;
  width: 100%;
  max-width: 1140px;
  height: 65px;
  background-color: var(--primary);
  position: fixed;
  left: 50%;
  transform: translateX(-50%);
  display: flex;
  justify-content: space-between;
  align-items: center;
  top:0px;
}
.logo-header{
  width: 120px;
  height: 60px;
  object-fit: contain;
  object-position: center center;
  margin-top: 4px;
  margin-bottom: -4px;
  margin-left: 40px;
}

.header-items-wrapper{
  display: flex;
  align-items: center;
  height: 100%;
}
.header-icons-wrapper{
  display: flex;
  gap:8px;
  padding: 0 16px;
}

.header-icon{
  height: 32px;
  width: 32px;
  background-color: #fff;
  transition: background-color .3s ease;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border: none;
  border-radius: 7px;
}
.header-icon:hover{
  background-color: var(--primary);
}
.header-hamburger-button{
  background-color: var(--secundary);
  height: 100%;
  width: 73px;
  transition: background-color .3s ease;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
  border: none;
}
.header-hamburger-button:hover{
  background-color: var(--darksecundary);
}
.facebook-icon,.tiktok-icon{
  width: 20px;
  height: 30px;
  fill: var(--secundary);
}
.instagram-icon{
  width: 20px;
  height: 30px;
  stroke-width: 1.7px;
  stroke: var(--secundary);
  fill: transparent;
}
.hamburger-icon{
  width: 24px;
  height: 24px;
  stroke: #fff;
  stroke-width: 3px;
}


.about-container{
  width: 100%;
  margin: 0 auto;
  padding-bottom: 20px;
  display: flex;
  flex-direction: column;
  align-items: center;
}



.about-logo-dimark{
  width: 250px;
  height: 120px;
  object-fit: contain;
}


.about-description {
  font-size: 18px;
  text-align: center;
  color: var(--gray-text);
  margin-top: 10px;
  width: 90%;
}
.about-description span{
  color: var(--secundary);
  font-weight: 700;
}

.about-features-wrapper{
  width: 100%;
  padding: 0px 16px;
  display: flex;
  flex-direction: column;
  justify-content: space-evenly;
  align-items: center;
  gap: 10px;
  margin-top: 40px;
}

.about-process-feature{
  display: flex;
  flex-direction: column;
  padding: 40px 50px;
  justify-content: center;
  align-items: center;
  background-color: transparent;
  background-image: linear-gradient(150deg, #2F2F2F 0%, #000000 100%);
  opacity: 1;
  width: 250px;
  height: 363px;
  border-radius: 30px;
}
.about-develop-feature{
  display: flex;
  flex-direction: column;
  padding: 40px 50px;
  justify-content: center;
  align-items: center;
  background-color: transparent;
  background-image: linear-gradient(150deg, #101010 31%, #931818 100%);
  opacity: 1;
  width: 250px;
  height: 460px;
  border-radius: 30px;
}
.about-thought-feature{
  display: flex;
  flex-direction: column;
  padding: 40px 50px;
  justify-content: center;
  align-items: center;
  background-color: transparent;
  background-image: linear-gradient(150deg, #2A2A2A 0%, #212121 100%);
  opacity: 1;
  width: 250px;
  height: 363px;
  border-radius: 30px;
}

.about-feature-title{
  font-weight: 200;
  font-size: 20px;
  color: #fff;
  margin-top: 20px;
}

.about-feature-subtitle{
  font-weight: 700;
  font-size: 32px;
  color: #fff;
}

.about-feature-description{
  font-weight: 400;
  font-size: 16px;
  margin-top: 40px;
  text-align: center;
  color: #fff;
}

.button{
  max-width: 80%;
  padding: 16px 32px;
  background-color: var(--secundary);
  cursor: pointer;
  transition: background-color .3s ease;
  font-size: 24px;
  font-weight: 700;
  color: #fff;
  margin-top: 40px;
  border: none;
  font-family: "Montserrat", sans-serif;
  text-decoration: none;
}
.button:hover{
  background-color: var(--primary);
}
/* About us Media */
@media (min-width:1000px) {

  .about-logo-dimark{
    width: 510px;
    height: 128px;
  }
  .about-container{
    width: 80%;
    padding: 50px 0px;
  }
  .about-description {
    font-size: 24px;
    margin-top: 60px;
  }
  .about-features-wrapper{
    width: 1110px;
    padding: 0px 16px;
    display: flex;
  flex-direction: row;
    gap: 32px;
    margin-top: 80px;
  }
  .about-process-feature,.about-develop-feature,.about-thought-feature{
    width: 328px;
  }
}
/* About us Media */

.suscees-web-stories-container{
  display: flex;
  margin-bottom: 100px;
}

.suscees-web-stories-image-container{
  display: none;
}
.suscees-web-stories-image{
  width: 100%;
  height: 700px;
}
.suscees-web-stories-content-container{
  width: 100%;
  display: flex;
  flex-direction: column;
  padding-left: 1rem;
}

.separator{
  background-color: var(--secundary);
  width: 178px;
  height: 7px;
  margin: 20px -5px 0px -45px;
}

.suscees-web-stories-content-title{
  margin-top: 20px;
  font-size: 44px;
  font-weight: 300;

}

.suscees-web-stories-content-title span{
  font-weight: 700;
}

.suscees-web-stories-content-subtitle{
  font-size: 24px;
  color: var(--gray-text);
  margin-top: 20px;
}

.suscees-web-stories-items-container{
  display: flex;
  flex-direction: column;
  gap: 8px;
  margin-top: 20px;
  padding-right: 20px;
}

.suscees-web-stories-item{
  width: 100%;
  height: 400px;
  overflow: hidden;
  border-radius: 20px;
}
.suscees-web-stories-item-1{
  background-image: url("/wp-content/themes/dimark/images/historiaexito1.jpg");
  background-position: top center;
  background-repeat: no-repeat;
  background-size: cover;
  transition: all 2.4s;
}
.suscees-web-stories-item-2{
  background-image: url("/wp-content/themes/dimark/images/historiaexito2.jpg");
  background-position: top center;
  background-repeat: no-repeat;
  background-size: cover;
  transition: all 2.4s;
}
.hover-web:hover {
  background-position-y: 100%;
  cursor: pointer;
}
/* Success web stories Media */
@media (min-width:1000px) {
  .suscees-web-stories-image-container{
    width: 50%;
    display: flex;
    flex-direction: column;
    align-items: end;
  }
  .suscees-web-stories-content-container{
    width: 50%;
    padding-left: 5rem;
  }
  .separator{
    margin: 35px -5px 10px -145px;
  }
  .suscees-web-stories-items-container{
    display: flex;
    flex-direction: row;
    gap: 8px;
    margin-top: 64px;
    padding-left: 20px;
    padding-right: 20px;
  }
  .suscees-web-stories-item{
    width: 50%;
    height: 600px;
  }
  .suscees-web-stories-content-title{
    margin-top: 80px;
  }
}
  /* Success web stories Media */


.sucess-seo-text-container{
  width: 90%;
  padding-left: 1rem;
}

.sucess-seo-text-container-separator{
  background-color: var(--secundary);
  width: 178px;
  height: 7px;
  margin: 35px -5px 10px 10px;
}

.success-seo-title{
  margin-top: 20px;
  width: 100%;
  font-weight: 300;
  font-size: 34px;
}

.success-seo-title span{
  font-weight: 700;
}

.sucess-seo-p{
  font-size: 24px;
  color: var(--gray-text);
  margin-top: 20px;
}

.success-seo-cases-container{
  width: 100%;
  display: flex;
  flex-direction: column;
  align-items: center;
  overflow: hidden;
  padding-bottom: 16px;
}

.success-seo-cases-wrapper{
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  gap: 16px;
  padding: 20px;
  margin-top: 40px;

}

.sucess-seo-case{
  background-color: var(--primary);
  height: 250px;
  width: 43%;
  padding: 8px;
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  border-radius: 20px;
}

.sucess-seo-case-p{
  color: var(--secundary);
}

.sucess-seo-case-title{
  font-size: 16px;
  color: #fff;
  font-weight: 700;
  text-align: center;
  line-height: 16px;
  margin-bottom: 20px;
}
.sucess-seo-case-subtitle{
  font-size: 12px;
  color: var(--gray-text);
}

.sucess-seo-case-button{
  padding: 8px 16px;
  background-color: #fff;
  color: var(--primary);
  font-weight: 700;
  border: none;
  font-size: 14px;
  font-family: "Montserrat", sans-serif;
  text-transform: uppercase;
  border-radius: 20px;
  margin-top: 20px;
  transition: all .3s ease;
}

.sucess-seo-case-button:hover{
  background-color: var(--secundary);
  color: #fff;
}

/* Success SEO Media */
@media (min-width:1000px) {
  .sucess-seo-text-container{
    width: 50%;
    padding-left: 5rem;
  }
  .success-seo-title{
  margin-top: 40px;
  width: 80%;
  font-weight: 300;
  font-size: 60px;
  }
  .success-seo-cases-wrapper{
    display: flex;
    flex-direction: row;
    flex-wrap: nowrap;
    gap: 16px;
    padding: 20px;
    margin-top: 40px;
  
  }
  .sucess-seo-case{
    max-width: 100%;
  }
  .sucess-seo-case-title{
    font-size: 28px;
    line-height: 28px;
  }
  .sucess-seo-case-subtitle{
    font-size: 16px;
    color: var(--gray-text);
  }
  
}
/* Success SEO Media */


.recognition-and-sales{
  width: 75%;
  margin: 0 auto;
  margin-top: 80px;
  display: flex;
  flex-direction: column;
  align-items: center;
}

.recognition-and-sales-title{
  font-size: 34px;
  font-weight: 700;
  color: var(--secundary);
  text-align: center;
}
.recognition-and-sales-p{
  font-size: 24px;
  color: var(--gray);
  text-align: center;
}

/* Recognition and sales Media */
@media (min-width:1000px) {
  .recognition-and-sales-title{
    font-size: 56px;
  }
  .recognition-and-sales-p{
    font-size: 30px;
  }
}
/* Recognition and sales Media */


.own-developments-container{
  display: flex;
  flex-direction: column;
  margin-top: 80px;
}

.own-developments-left-container{
  display: none;
}

.own-developments-left-container-img{
  width: 100%;
}

.own-developments-right-container{
  width: 100%;
  height: 550px;
  background-color: var(--darkprimary);
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;

}
.clipping{
  clip-path: polygon(0 0, 100% 0, 100% 85%, 0% 100%);
}

.own-developments-right-container-separator{
  background-color: #fff;
  width: 66%;
  height: 2px;
}

.own-developments-right-container-title{
  width: 80%;
  font-size: 55px;
  line-height: 55px;
  text-align: center;
  font-weight: 300;
  margin-top: 20px;
  color: #fff;
}

.own-developments-right-container-title span{
  font-weight: 900;
  color: inherit;
}
/* Own devvelopments Media */
@media (min-width:1000px) {
  .own-developments-container{
    flex-direction: row;
  }
  .own-developments-right-container{
    width: 50%;
    height: 550px;
  
  }
  .own-developments-left-container{
    width: 50%;
    display: flex;
    justify-content: center;
    align-items: center;
    padding: 0 64px;
  }
}
/* Own devvelopments Media */

.instaplanner-container{
  display: flex;
  flex-direction: column-reverse;
  margin-top: 80px;
}

.instaplanner-left-container{
  width: 100%;
  display: flex;
  flex-direction: column;
  justify-items: end;
  position: relative;
}
.instaplanner-spacer{
  width: 100%;
  height: 300px;
  position: absolute;
  background-color: transparent;
  background-image: linear-gradient(150deg, #181818 63%, #c10018 100%);
}

.instaplanner-img{
  width: 400px;
  height: 500px;
  object-fit: contain;
  margin-top: 40px;
  margin-bottom: -80px;
  z-index: 20;
}

.instaplanner-right-container{
  width: 100%;
  padding-left: 20px;
  margin-bottom: 20px;
}

.mark-button{
  background-color: var(--primary);
  margin: 40px 40px 0 0;
  font-weight: 700;
  color: #fff;
  border: none;
  border-radius: 40px;
  padding: 8px 16px;
}

.instaplanner-title{
  margin-top: 40px;
  font-size: 44px;
  font-weight: 300;
}

.instaplanner-p1{
  font-size: 24px;
  font-weight: 500;
  color: var(--secundary);
  margin-top: 16px;
}
.instaplanner-p2{
  font-size: 30px;
  font-weight: 300;
  color: var(--gray-text);
  margin-top: 50px;
  width: 70%;
}

.icon-box{
  display: flex;
  gap: 16px;
  margin-top: 64px;
}
.icon-box-icon-container{
  width: 64px;
  height: 64px;
  background-color: var(--primary);
  border: none;
  border-radius: 50px;
  display: flex;
  justify-content: center;
  align-items: center;
  color: #fff;
}

.icon-box-title{
  font-size: 24px;
  font-weight: 700;
  text-transform: uppercase;
}

.icon-box-description{
  font-weight: 300;
  color: var(--gray-text);
  width: 70%;
}
.icon-box-content{
  width: 80%;
}
/* Instaplanner Media */
@media (min-width:1000px) {
  .instaplanner-container{
    display: flex;
    flex-direction: row;
    margin-top: 80px;
  }
  .instaplanner-right-container{
    width: 50%;
    padding-left: 5rem;
    margin-bottom: 0px;
  }
  .instaplanner-left-container{
    width: 50%;
  }
  .instaplanner-spacer{
    width: 100%;
    height: 65%;
   }
  
  .instaplanner-img{
    width: 596px;
    height: 800px;
    margin-top: 160px;
  }
  .instaplanner-title{
    font-size: 60px;
  }
  
  .instaplanner-p1{
    font-size: 30px;
  }
  .instaplanner-p2{
    font-size: 20px;
  }
}
/* Instaplanner Media */
.instragrammer-container{
  display: flex;
  flex-direction: column;
  align-items: center;
}

.instragrammer-content-wrapper {
  display: flex;
  flex-direction: column;
  margin-top: 80px;
}

.instragrammer-content-wrapper-left-container{
  width: 100%;
  padding-left: 20px;
  padding-bottom: 20px;
}

.instagrammer-title{
  margin-top: 10px;
  font-size: 44px;
  font-weight: 300;
}

.instagrammer-p1{
  font-size: 24px;
  font-weight: 500;
  color: var(--secundary);
  margin-top: 10px;
}

.instagrammer-p2{
  font-size: 30px;
  font-weight: 400;
  color: var(--gray-text);
  margin-top: 20px;
  width: 90%;
}

.instagrammer-p3{
  font-size: 28px;
  font-weight: 300;
  color: var(--gray-text);
  margin-top: 20px;
  width: 90%;
}


.instragrammer-content-wrapper-right-container{
 width: 100%;
 display: flex;
 flex-direction: column;
 align-items: center;
 position: relative;
}

.instragramer-spacer{
  width: 100%;
  height: 300px;
  background-color: transparent;
  background-image: linear-gradient(210deg, #181818 63%, #c10018 100%);
  position: absolute;
}
.instagramer-img{
  width: 350px;
  height: 600px;
  object-fit: contain;
  margin-top: 60px;
  margin-bottom: -60px;
  z-index: 20;
}
/* Instagramer Media */
@media (min-width:1000px) {
  .instragrammer-content-wrapper {
    flex-direction: row;
  }
  .instragrammer-content-wrapper-left-container{
    width: 50%;
    padding-left: 64px;
    padding-bottom: 0px;
  }
  .instagrammer-title{
    font-size: 60px;
    margin-top: 40px;
  }
  
  .instagrammer-p1{
    font-size: 30px;
    margin-top: 16px;
  }
  
  .instagrammer-p2{
    font-size: 28px;
    width: 70%;
    margin-top: 50px;
  }
  
  .instagrammer-p3{
    font-size: 20px;
    width: 70%;
    margin-top: 50px;
  }
  .instragrammer-content-wrapper-right-container{
    width: 50%;
  }
  .instragramer-spacer{
    height: 98%;
  }
}
/* Instagramer Media */

.map-section{
  width: 100%;
  display: flex;
  flex-direction: column;
  margin-top: 50px;
  overflow: hidden;
}

.map-section-left-container{
  width: 100%;
  display: flex;
  flex-direction: column;
  justify-content: center;
  align-items: center;
}

.logo3{
  width: 175px;
  height: 189px;
}

.map-section-left-container-p{
  font-size: 32px;
  font-weight: 700;
  text-align: center;
  color: var(--primary);
  margin-top: 20px;
}
.map-section-right-container{
  width: 100%;
  overflow: hidden;
  height: 600px;
  position: relative;
}

.mapmundi-img{
  width: 100%;
  height: 500px;
  object-fit: contain;
  transform: scale(1);
  position: absolute;
  inset: 0;
  left: 20px;
}
/* Mapmundi Media */
@media (min-width:1000px) {
  .map-section{
    flex-direction: row;
    margin-top: 0px;
  }
  .map-section-left-container{
    width: 50%;
  }
  .map-section-right-container{
    width: 50%;
    height: 1200px;
  }
  .mapmundi-img{
    width: 1000px;
    height: 1000px;
    transform: scale(1.1);
    left: 100px;
  }
}
/* Mapmundi Media */
.footer{
  display: flex;
  flex-direction: column;
  margin-top: 100px;
  overflow: hidden;
}
.footer-left-container{
  display: flex;
  flex-direction: column;
}
.footer-left-container .left-container{
  width: 100%;
  min-height: 546px;
  display: flex;
  flex-direction: column;
  justify-content: center;
  background-color: var(--darkprimary);
  padding-left: 20px;
  padding-bottom: 40px;
  padding-top: 40px;
}

.left-container .logo-img{
  width: 325px;
  height: 80px;
  object-fit: contain;
}

.left-container .separator{
  width: 100%;
  height: 1px;
  background-color: #fff;
  margin: 40px 0;
  opacity: 0.2;
}

.left-container .list-icon-wrapper{
  display: flex;
  flex-direction: column;
  gap: 40px;
}

.list-icon-wrapper .list-icon{
  display: flex;
  flex-direction: column;
  gap: 4px;
}

.list-icon h3{
  color: #fff;
  opacity: 0.5;
  font-size: 16px;
  font-weight: 300;
  text-transform: uppercase;
  margin-bottom: 20px;
}

.list-icon p{
  font-size: 20px;
  font-weight: 700;
  color: #fff;
}

.footer .icons-wrapper {
  display: flex;
  gap: 20px;
  margin-top: 40px;
}

.icons-wrapper button{
  height: 32px;
  width: 32px;
  background-color: var(--primary);
  transition: color .3s ease;
  display: flex;
  justify-content: center;
  align-items: center;
  border:  none;
  border-radius: 7px;
}
.icons-wrapper button:hover{
 
  background-color: var(--darkprimary);
}

.icons-wrapper .facebook-icon,.icons-wrapper .tiktok-icon{
  fill: #fff;
  cursor: pointer;
}
.icons-wrapper .instagram-icon{
  stroke: #fff;
  cursor: pointer;
}

.footer .right-container{
  width: 100%;
  min-height: 546px;
  display: flex;
  position: relative;
  justify-content: start;
  align-items: center;
  background-color: #efefef;
  padding-left: 20px;
}

.footer-right-overlay-bg{
  background-image: url("/wp-content/themes/dimark/images/logo4.png");
  background-position: 0px center;
  background-repeat: no-repeat;
  background-size: 400px 400px;
  opacity: 0.1;
  position: absolute;
  width: 100%;
  height: 100%;
}

.right-container .content-container{
  display: flex;
  flex-direction: column;
  align-items: start;
  z-index: 10;
  padding: 0 35px 85px 10px;
  gap: 32px;
}
.content-container .separator{
  background-color: var(--secundary);
  width: 100px;
  height: 5px;
  margin: 30px -5px -30px -145px;
}

.right-container .content-container h2{
  font-size: 44px;
  font-weight: 900;
  color: var(--primary);
  text-align: center;
  margin-top: 8px;
}

.right-container .content-container p{
  font-size: 34px;
  font-weight: 300;
  color: var(--primary);
  text-align: center;
  margin-top: 20px;
  
}

.right-container .content-container .button{
  background-color: #fff;
  color: var(--secundary);
}
.right-container .content-container .button:hover{
  background-color: var(--secundary);
  color: #fff;
}

.footer .bottom-container{
  background-color: #000000;
  height: 60px;
  display: flex;
  flex-direction: column;
  justify-content: space-between;
  align-items: center;
  padding: 20px;
}

.bottom-container .menu{
  display: flex;
  gap: 16px;
}
.bottom-container .menu a{
  color: #fff;
  opacity: 0.5;
  text-decoration: none;
}
.bottom-container .menu a:hover{
  opacity: 1;
}

.bottom-container p{
  color: #fff;
  opacity: 0.5;
  text-decoration: none;
}

/* Mapmundi Media */
@media (min-width:1000px) {
  .footer-left-container{
    flex-direction: row;
  }
  .footer-left-container .left-container{
    width: 50%;
    padding-bottom: 0px;
    padding-top: 0px;
  }
  .left-container .list-icon-wrapper{
    display: flex;
    flex-direction: row;
  }
  .footer .right-container{
    width: 50%;
    padding-left: 100px;
  }
  .footer .bottom-container{
    height: 100px;
    flex-direction: row;
    justify-content: space-between;
    padding: 0 100px 0 100px;
  }
}

/* Mapmundi Media */