<?php
/**
 * Template-part: avi-strip
 */
?>
<div class="avi-strip">
  <div class="avi-badge">Nuevo</div>
  <div class="avi-info">
    <div class="avi-title">🤖 Somos los creadores de AVI Asistente</div>
    <div class="avi-sub">Automatización inteligente con IA para transformar los procesos de tu empresa las 24 horas</div>
  </div>
  <a href="https://dimark.co/desarrollos-propios/" target="_blank" class="avi-btn">Conocer AVI →</a>
</div>
