<?php
/**
 * Front Page — Home generado automáticamente.
 * Cada sección es un template-part independiente.
 */
get_header(); ?>

<?php get_template_part('template-parts/hero'); ?>

<?php get_template_part('template-parts/stats'); ?>

<?php get_template_part('template-parts/partners'); ?>

<?php get_template_part('template-parts/avi-strip'); ?>

<?php get_template_part('template-parts/presencia-mundial'); ?>

<?php get_template_part('template-parts/casos'); ?>

<?php get_template_part('template-parts/certified'); ?>

<?php get_template_part('template-parts/servicios-independientes'); ?>

<?php get_template_part('template-parts/lightbox'); ?>

<?php get_footer();
