<?php

// Asegúrate de que el tema tenga soporte para Elementor
function my_theme_setup()
{
    // Soporte para Elementor
    add_theme_support('elementor');

    // Soporte para imágenes destacadas
    add_theme_support('post-thumbnails');

    // Soporte para títulos
    add_theme_support('title-tag');

    // Soporte para el logotipo personalizado
    add_theme_support('custom-logo');

    // Soporte para el encabezado personalizado
    add_theme_support('custom-header');
}
add_action('after_setup_theme', 'my_theme_setup');

// Encolar los estilos y scripts del tema
function add_asset()
{
    // Encolar el estilo principal del tema
    wp_enqueue_style('style', get_stylesheet_uri());

    // Encolar estilos y scripts personalizados
     wp_enqueue_style('custom', get_template_directory_uri() . '/assets/css/index.css', [], '1.0.0.8');
    // wp_enqueue_style('custom', get_template_directory_uri() . '/assets/js/index.js', [], '1.0.0.3');

    // Asegurarse de que Elementor puede cargar sus estilos
    if (class_exists('Elementor\Plugin')) {
        wp_enqueue_style('elementor-frontend', ELEMENTOR_ASSETS_URL . 'css/frontend.min.css', [], ELEMENTOR_VERSION);
    }
}
add_action('wp_enqueue_scripts', 'add_asset');

// Encolar estilos para el editor de bloques de Gutenberg
function vdv_aprendegutenberg_block_editor_styles()
{
    wp_enqueue_style('vdv-aprendegutenberg-block-editor-styles', get_theme_file_uri('/assets/css/styles.editor.css'), false, '1.0', 'all');
}
add_action('enqueue_block_editor_assets', 'vdv_aprendegutenberg_block_editor_styles');

// Añadir estilos globales personalizados de Elementor si es necesario
// function my_custom_elementor_global_styles()
// {
//     if (class_exists('Elementor\Plugin')) {
//         echo '<style>
//             :root {
//                    --e-global-color-primary: #B50D0D;
//     --e-global-color-secondary: #3F3F3F;
//     --e-global-color-text: #8A8A8A;
//     --e-global-color-accent: #931818;
//     --e-global-color-b2a7d16: #181818;
//     --e-global-typography-primary-font-family: "Work Sans";
//     --e-global-typography-primary-font-weight: 600;
//     --e-global-typography-secondary-font-family: "Work Sans";
//     --e-global-typography-secondary-font-weight: 400;
//     --e-global-typography-text-font-family: "Work Sans";
//     --e-global-typography-text-font-weight: 400;
//     --e-global-typography-text-line-height: 0px;
//     --e-global-typography-accent-font-family: "Work Sans";
//     --e-global-typography-accent-font-weight: 500;
//     color: var( --e-global-color-text );
//     font-family: "Work Sans", Sans-serif;
//             }
//         </style>';
//     }
// }
// add_action('wp_head', 'my_custom_elementor_global_styles');

// Registrar menús de navegación
function register_my_menus()
{
    register_nav_menus(array(
        'menu-first' => __('Menu First'),
    ));
}
add_action('init', 'register_my_menus');

// Función para obtener y establecer vistas de publicaciones
function getPostViews($postID)
{
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if ($count == '') {
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return "0 View";
    }
    return $count . ' Views';
}

function setPostViews($postID)
{
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if ($count == '') {
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    } else {
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}

// Evitar problemas con el prefetching añadiendo vistas extra
remove_action('wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);

// Funciones de precios con shortcode
