<?php
/**
 * Template-part: lightbox
 */
?>
<div class="lightbox" id="lightbox">
  <span class="lightbox-close" id="lightboxClose">&times;</span>
  <img id="lightboxImg" src="" alt="Vista detallada">
</div>
