<?php
/**
 * Template-part: presencia-mundial
 */
?>
<section class="world-sec" id="presencia">
  <div class="world-glow"></div>
  <div class="world-inner">
    <div class="world-text">
      <div class="eyebrow"><span class="eyebrow-line"></span>Presencia internacional</div>
      <h2 class="sec-title">Con presencia<br>a nivel mundial</h2>
      <p class="sec-sub">Acompañamos el crecimiento digital de empresas en LATAM y USA. Donde esté tu negocio, estamos listos para hacerlo crecer.</p>
      <a href="https://dimark.co/contactenos/" target="_blank" class="btn-red">Contáctenos →</a>
    </div>
    <div class="world-img-wrap">
      <img class="world-img" src="https://dimark.co/wp-content/uploads/2025/07/mapmundi.png" alt="Mapa mundial Dimark" loading="lazy">
    </div>
  </div>
</section>

<!-- SERVICIOS + PLANES -->
<section class="sec sec-bg1" id="servicios" style="padding-bottom:0;border-bottom:none">
  <div style="max-width:640px">
    <div class="eyebrow"><span class="eyebrow-line"></span>Lo que hacemos</div>
    <h2 class="sec-title">Servicios que<br>generan resultados</h2>
    <p class="sec-sub">Selecciona los que tu negocio necesita y armamos el combo ideal para ti — al instante.</p>
  </div>
</section>

<section class="sec sec-bg1" id="planes" style="padding-top:28px;border-top:none">
  <div class="combo-layout">
    <div>
      <div class="svc-grid" id="svcGrid">
        <div class="svc-card" data-s="google"><div class="svc-chk">✓</div><span class="svc-ico">🔍</span><div class="svc-name">Google Ads</div><div class="svc-desc">Campañas SEM de alto rendimiento con máximo retorno de inversión en buscadores</div><span class="svc-pill">SEM / PPC</span></div>
        <div class="svc-card" data-s="meta"><div class="svc-chk">✓</div><span class="svc-ico">📣</span><div class="svc-name">Meta Ads</div><div class="svc-desc">Publicidad en Facebook e Instagram con segmentación precisa y alta conversión</div><span class="svc-pill">Redes sociales</span></div>
        <div class="svc-card" data-s="ugc"><div class="svc-chk">✓</div><span class="svc-ico">🎥</span><div class="svc-name">UGC Videos</div><div class="svc-desc">Contenido de video auténtico y nativo para maximizar el rendimiento de tus anuncios</div><span class="svc-pill">2 videos / mes</span></div>
        <div class="svc-card" data-s="web"><div class="svc-chk">✓</div><span class="svc-ico">🌐</span><div class="svc-name">Diseño Web</div><div class="svc-desc">Landing pages y sitios web diseñados para convertir visitantes en clientes</div><span class="svc-pill">Conversión</span></div>
        <div class="svc-card" data-s="seo"><div class="svc-chk">✓</div><span class="svc-ico">📈</span><div class="svc-name">SEO</div><div class="svc-desc">Posicionamiento orgánico sostenible en primeras posiciones de Google</div><span class="svc-pill">Orgánico</span></div>
        <div class="svc-card" data-s="avi"><div class="svc-chk">✓</div><span class="svc-ico">🤖</span><div class="svc-name">AVI Asistente</div><div class="svc-desc">Nuestro asistente de IA propio para automatizar ventas y atención 24/7</div><span class="svc-pill">IA propia</span></div>
      </div>
    </div>
    <div class="combo-sticky">
      <div style="margin-bottom:16px">
        <div class="eyebrow"><span class="eyebrow-line"></span>Elige tu plan</div>
        <h2 class="sec-title" style="font-size:clamp(22px,3vw,36px)">Tu combo<br>a la medida</h2>
        <p class="sec-sub" style="font-size:13px">Selecciona los servicios y al instante te mostramos el plan ideal.</p>
      </div>
      <div class="plan-box">
        <div class="plan-empty" id="planEmpty">
          <span class="plan-empty-ico">⚙️</span>
          <div class="plan-empty-t">Selecciona tus servicios</div>
          <div class="plan-empty-s">Haz clic en las tarjetas de servicios para ver tu plan ideal al instante</div>
        </div>
        <div class="plan-fill" id="planFill">
          <div class="plan-l">
            <div class="plan-ey" id="planEy">Plan recomendado</div>
            <div class="plan-name" id="planName" style="font-size:28px">—</div>
            <div class="plan-inc-lbl">Incluye</div>
            <ul class="plan-list" id="planList"></ul>
          </div>
          <div class="plan-r" style="border-top:1px solid var(--border)">
            <div class="plan-r-t">¿Te interesa este plan?</div>
            <div class="plan-r-s">Habla ahora mismo con uno de nuestros expertos y recibe una propuesta personalizada sin ningún compromiso.</div>
            <a href="#" class="btn-wa" id="planWA" target="_blank">
              <svg width="20" height="20" viewBox="0 0 24 24" fill="white"><path d="M17.472 14.382c-.297-.149-1.758-.867-2.03-.967-.273-.099-.471-.148-.67.15-.197.297-.767.966-.94 1.164-.173.199-.347.223-.644.075-.297-.15-1.255-.463-2.39-1.475-.883-.788-1.48-1.761-1.653-2.059-.173-.297-.018-.458.13-.606.134-.133.298-.347.446-.52.149-.174.198-.298.298-.497.099-.198.05-.371-.025-.52-.075-.149-.669-1.612-.916-2.207-.242-.579-.487-.5-.669-.51-.173-.008-.371-.01-.57-.01-.198 0-.52.074-.792.372-.272.297-1.04 1.016-1.04 2.479 0 1.462 1.065 2.875 1.213 3.074.149.198 2.096 3.2 5.077 4.487.709.306 1.262.489 1.694.625.712.227 1.36.195 1.871.118.571-.085 1.758-.719 2.006-1.413.248-.694.248-1.289.173-1.413-.074-.124-.272-.198-.57-.347z"/><path d="M12 0C5.373 0 0 5.373 0 12c0 2.124.554 4.118 1.523 5.845L0 24l6.337-1.507A11.95 11.95 0 0012 24c6.627 0 12-5.373 12-12S18.627 0 12 0zm0 21.818a9.808 9.808 0 01-5.034-1.384l-.36-.214-3.733.888.917-3.63-.235-.374A9.797 9.797 0 012.182 12C2.182 6.589 6.589 2.182 12 2.182S21.818 6.589 21.818 12 17.411 21.818 12 21.818z"/></svg>
              Contactar por WhatsApp
            </a>
            <a href="tel:+573203920599" class="btn-call">📞 Llamar: 320 392 05 99</a>
            <div class="plan-trust">
              <div class="trust-it">⚡ Respuesta &lt;30 min</div>
              <div class="trust-it">🎯 Asesoría gratis</div>
              <div class="trust-it">🔒 Sin compromiso</div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</section>
