<?php
/**
 * Footer — Compartido por todas las páginas.
 */
?>



<footer>
  <div class="footer-top">
    <div>
      <img class="footer-logo-img" src="https://dimark.co/wp-content/themes/dimark/images/logoheader.png" alt="Dimark">
      <p class="footer-tag">Obsesivos por el crecimiento de tu negocio. Medellín, Colombia — con presencia en LATAM y USA.</p>
      <div class="footer-sedes"><strong>Medellín, Colombia</strong><br>Calle 31 s 47 - 15<br><br><strong>Miami, USA</strong><br>5001 sw 173 ave. Miramar - FL</div>
      <div class="socials">
        <a class="soc" href="https://www.instagram.com/dimark.co/" target="_blank">📷</a>
        <a class="soc" href="https://www.facebook.com/profile.php?id=100043754966551" target="_blank">📘</a>
        <a class="soc" href="https://www.tiktok.com/@dimark.co" target="_blank">🎵</a>
        <a class="soc" href="https://api.whatsapp.com/send/?phone=573203920599" target="_blank">💬</a>
      </div>
    </div>
    <div class="footer-col">
      <div class="footer-col-t">Servicios</div>
      <a href="https://dimark.co/servicios/" target="_blank">Google Ads</a>
      <a href="https://dimark.co/servicios/" target="_blank">Meta Ads</a>
      <a href="https://dimark.co/servicios/seo/" target="_blank">SEO</a>
      <a href="https://dimark.co/servicios/pagina-web/" target="_blank">Diseño Web</a>
      <a href="https://dimark.co/desarrollos-propios/" target="_blank">AVI Asistente</a>
    </div>
    <div class="footer-col">
      <div class="footer-col-t">Empresa</div>
      <a href="https://dimark.co/somos-grupo-dimark/" target="_blank">Quiénes somos</a>
      <a href="https://dimark.co/casos-de-exito/web/" target="_blank">Casos de éxito</a>
      <a href="https://dimark.co/desarrollos-propios/" target="_blank">Desarrollos propios</a>
      <a href="https://dimark.co/contactenos/" target="_blank">Contacto</a>
    </div>
    <div class="footer-col">
      <div class="footer-col-t">Contacto</div>
      <a href="tel:+573203920599">📞 320 392 05 99</a>
      <a href="mailto:info@dimark.co">✉️ info@dimark.co</a>
      <a href="https://api.whatsapp.com/send/?phone=573203920599" target="_blank">💬 WhatsApp directo</a>
    </div>
  </div>
  <div class="footer-bottom">
    <span>© 2025 Dimark SEO. Todos los derechos reservados.</span>
    <span>Hecho con ❤️ en Medellín para el mundo</span>
  </div>
</footer>

<?php wp_footer(); ?>
</body>
</html>
