<?php
/**
 * Template-part: hero
 */
?>
<section class="hero" id="inicio">
  <div class="hero-glow"></div>
  <div class="hero-vline"></div>
  <img class="hero-logobg" src="https://dimark.co/wp-content/uploads/2025/07/mapmundi.png" alt="">

  <div class="hero-tag">
    <span class="hero-tag-line"></span>
    Agencia Digital · Medellín · LATAM · USA
  </div>

  <h1>
    Hacemos crecer
    <span class="h1-red">tu negocio</span>
    <span class="h1-ghost">digitalmente</span>
  </h1>

  <p class="hero-desc">
    <b>+10 años</b> convirtiendo inversión digital en resultados medibles.<br>
    Google Ads · Meta Ads · SEO · Diseño Web · Automatización con IA.
  </p>

  <div class="hero-btns">
    <a href="#planes" class="btn-red">Elegir mi plan →</a>
    <a href="#casos" class="btn-ghost">Ver casos de éxito</a>
  </div>

  <div class="hero-scroll">
    <span class="hero-scroll-line"></span>
    Scroll para explorar
  </div>
</section>
