<?php get_header(); ?>
<main class="wrap" style="padding:140px 24px;text-align:center;min-height:60vh;">
    <h1 style="font-size:5rem;">404</h1>
    <p>Esta página no existe.</p>
    <p><a href="<?php echo esc_url(home_url('/')); ?>">← Volver al inicio</a></p>
</main>
<?php get_footer();
