        <footer class="footer">
          <div class="footer-left-container">
            <div class="left-container">
              <img src="/wp-content/themes/dimark/images/logo5.png" class="logo-img" alt="logo dimakr" />
              <div class="separator"></div>
              <div class="list-icon-wrapper">
                <div class="list-icon">
                  <h3>
                    Contacto
                  </h3>
                  <p>+57 320 392 05 99</p>
                  <p>WhatsApp</p>
                  <p>info@dimark.co</p>
                </div>
                <div class="list-icon">
                  <h3>
                    Sedes
                  </h3>
                  <p>
                    Medellín - Colombia
                  </p>
                  <p>Calle 31 s 47 - 15</p>
                  <p>Miami - USA</p>
                  <p>
                    5001 sw 173 ave. Miramar -Fl
                  </p>
                </div>
              </div>
              <div class="icons-wrapper">
                <a href="https://www.facebook.com/profile.php?id=100043754966551" target="_blank">
                  <svg xmlns="http://www.w3.org/2000/svg" width="10" height="16" viewBox="0 0 24 24" fill="currentColor" class="facebook-icon icon icon-tabler icons-tabler-filled icon-tabler-brand-facebook">
                    <path stroke="none" d="M0 0h24v24H0z" fill="none" />
                    <path d="M18 2a1 1 0 0 1 .993 .883l.007 .117v4a1 1 0 0 1 -.883 .993l-.117 .007h-3v1h3a1 1 0 0 1 .991 1.131l-.02 .112l-1 4a1 1 0 0 1 -.858 .75l-.113 .007h-2v6a1 1 0 0 1 -.883 .993l-.117 .007h-4a1 1 0 0 1 -.993 -.883l-.007 -.117v-6h-2a1 1 0 0 1 -.993 -.883l-.007 -.117v-4a1 1 0 0 1 .883 -.993l.117 -.007h2v-1a6 6 0 0 1 5.775 -5.996l.225 -.004h3z" />
                  </svg>
                </a>
                <a href="https://www.instagram.com/dimark.co/" target="_blank">
                  <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="instagram-icon icon icon-tabler icons-tabler-outline icon-tabler-brand-instagram">
                    <path stroke="none" d="M0 0h24v24H0z" fill="none" />
                    <path d="M4 4m0 4a4 4 0 0 1 4 -4h8a4 4 0 0 1 4 4v8a4 4 0 0 1 -4 4h-8a4 4 0 0 1 -4 -4z" />
                    <path d="M12 12m-3 0a3 3 0 1 0 6 0a3 3 0 1 0 -6 0" />
                    <path d="M16.5 7.5l0 .01" />
                  </svg>
                </a>
                <a href="https://www.tiktok.com/@dimark.co" target="_blank">
                  <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="currentColor" class="tiktok-icon icon icon-tabler icons-tabler-filled icon-tabler-brand-tiktok">
                    <path stroke="none" d="M0 0h24v24H0z" fill="none" />
                    <path d="M16.083 2h-4.083a1 1 0 0 0 -1 1v11.5a1.5 1.5 0 1 1 -2.519 -1.1l.12 -.1a1 1 0 0 0 .399 -.8v-4.326a1 1 0 0 0 -1.23 -.974a7.5 7.5 0 0 0 1.73 14.8l.243 -.005a7.5 7.5 0 0 0 7.257 -7.495v-2.7l.311 .153c1.122 .53 2.333 .868 3.59 .993a1 1 0 0 0 1.099 -.996v-4.033a1 1 0 0 0 -.834 -.986a5.005 5.005 0 0 1 -4.097 -4.096a1 1 0 0 0 -.986 -.835z" />
                  </svg>
                </a>
              </div>
            </div>
            <div class="right-container">
              <div class="footer-right-overlay-bg"></div>
              <div class="content-container">
                <div class="separator"></div>
                <h2 class="text-5xl font-black text-primary text-center mb-2">
                  ¿Tienes una idea?
                </h2>
                <p class="text-3xl font-light text-primary mb-8">
                  Nosotros la hacemos realidad…
                </p>
                <a href="https://dimark.co/contactenos/" class="button">
                  Contáctanos
                </a>
              </div>
            </div>
          </div>
          <div class="bottom-container">
            <div class="menu">
              <a href="https://dimark.co/">Inicio</a>
              <a href="https://dimark.co/somos-grupo-dimark/">Quienes Somos</a>
              <a href="https://dimark.co/servicios/">Servicios</a>
              <a href="https://dimark.co/contactenos/">Contáctenos</a>
            </div>
			  <p></p>
          </div>
        </footer>
        <script src="<?= get_template_directory_uri() ?>/assets/js/index.js"></script>

		
        </body>

        </html>