<?php get_header(); ?>

<?php global $wp;
if (home_url($wp->request) == 'https://dimark.co') : ?>

<style>
*,*::before,*::after{box-sizing:border-box;margin:0;padding:0}
:root{
  --red:#B50D0D;--red2:#931818;--red3:#c01515;
  --black:#181818;--black2:#0d0d0d;
  --dark:#1f1f1f;--dark2:#252525;--dark3:#2c2c2c;
  --gray:#8A8A8A;--gray2:#3F3F3F;
  --white:#ffffff;
  --border:rgba(255,255,255,0.07);
  --border2:rgba(255,255,255,0.13);
  --r:6px;--rl:12px;
  --gutter:max(52px, calc((100% - 1400px) / 2));
}
@media(max-width:960px){:root{--gutter:20px}}
html{scroll-behavior:smooth}
body{font-family:'Work Sans',sans-serif;background:var(--black);color:var(--white);overflow-x:hidden}
a{text-decoration:none;color:inherit}
img{display:block;max-width:100%}
::-webkit-scrollbar{width:3px}
::-webkit-scrollbar-thumb{background:var(--red)}


/* HERO */
.hero{min-height:100vh;background:var(--black2);display:flex;flex-direction:column;justify-content:center;padding:130px var(--gutter) 90px;position:relative;overflow:hidden}
.hero::before{content:'';position:absolute;inset:0;background-image:linear-gradient(rgba(255,255,255,.016) 1px,transparent 1px),linear-gradient(90deg,rgba(255,255,255,.016) 1px,transparent 1px);background-size:72px 72px;pointer-events:none}
.hero::after{content:'';position:absolute;bottom:0;left:0;right:0;height:1px;background:linear-gradient(90deg,transparent,var(--red),transparent)}
.hero-glow{position:absolute;top:0;right:0;bottom:0;width:45%;background:radial-gradient(ellipse at 80% 50%,rgba(181,13,13,0.08) 0%,transparent 65%);pointer-events:none}
.hero-vline{position:absolute;top:12%;right:9%;bottom:12%;width:1px;background:linear-gradient(to bottom,transparent,rgba(181,13,13,.25),transparent)}
.hero-logobg{position:absolute;right:3%;top:50%;transform:translateY(-50%);opacity:.28;pointer-events:none;width:min(620px,46vw);filter:drop-shadow(0 0 50px rgba(181,13,13,.45))}

.hero-tag{display:inline-flex;align-items:center;gap:12px;font-size:11px;font-weight:700;letter-spacing:3px;text-transform:uppercase;color:var(--red);margin-bottom:28px}
.hero-tag-line{width:36px;height:2px;background:var(--red)}

.hero h1{font-weight:900;font-size:clamp(50px,7.8vw,100px);line-height:.9;letter-spacing:-2px;text-transform:uppercase;margin-bottom:32px;max-width:860px;position:relative;z-index:1}
.h1-red{color:var(--red);display:block}
.h1-ghost{display:block;color:var(--white)}

.hero-desc{font-size:17px;font-weight:300;color:var(--gray);line-height:1.8;max-width:560px;margin-bottom:44px;position:relative;z-index:1}
.hero-desc b{color:var(--white);font-weight:600}

.hero-btns{display:flex;gap:14px;flex-wrap:wrap;position:relative;z-index:1;margin-bottom:80px}
.btn-red{background:var(--red);color:#fff;padding:15px 36px;border-radius:var(--r);font-family:'Work Sans',sans-serif;font-size:13px;font-weight:700;text-transform:uppercase;letter-spacing:1px;border:none;cursor:pointer;display:inline-block;transition:background .2s,transform .15s,box-shadow .2s}
.btn-red:hover{background:var(--red2);transform:translateY(-2px);box-shadow:0 10px 32px rgba(181,13,13,.5)}
.btn-ghost{background:transparent;color:#fff;padding:15px 36px;border-radius:var(--r);font-family:'Work Sans',sans-serif;font-size:13px;font-weight:700;text-transform:uppercase;letter-spacing:1px;border:1.5px solid rgba(255,255,255,.18);cursor:pointer;display:inline-block;transition:all .2s}
.btn-ghost:hover{border-color:#fff;background:rgba(255,255,255,.05);transform:translateY(-2px)}

.hero-scroll{position:absolute;bottom:34px;left:var(--gutter);display:flex;align-items:center;gap:12px;font-size:11px;font-weight:600;letter-spacing:2.5px;text-transform:uppercase;color:var(--gray2)}
.hero-scroll-line{width:52px;height:1px;background:var(--gray2)}

/* STATS */
.stats{display:grid;grid-template-columns:repeat(5,1fr);background:var(--dark);border-bottom:1px solid var(--border);padding:0 var(--gutter)}
.stat{padding:34px 22px;text-align:center;border-right:1px solid var(--border);position:relative;overflow:hidden;transition:background .2s;cursor:default}
.stat::after{content:'';position:absolute;bottom:0;left:0;right:0;height:0;background:var(--red);transition:height .25s}
.stat:hover::after{height:3px}
.stat:last-child{border-right:none}
.stat:hover{background:var(--dark2)}
.stat-n{font-weight:900;font-size:44px;line-height:1;color:var(--white);margin-bottom:7px}
.stat-n .acc{color:var(--red)}
.stat-l{font-size:12px;font-weight:500;color:var(--gray);line-height:1.45;text-transform:uppercase;letter-spacing:.5px}

/* PARTNERS */
.partners{background:var(--dark);padding:22px var(--gutter);border-bottom:1px solid var(--border);display:flex;align-items:center;gap:40px;flex-wrap:wrap}
.partners-lbl{font-size:10px;font-weight:700;letter-spacing:2.5px;text-transform:uppercase;color:var(--gray2);white-space:nowrap}
.partners-sep{width:1px;height:30px;background:var(--border2)}
.partner-row{display:flex;gap:12px;flex-wrap:wrap}
.partner{display:flex;align-items:center;gap:10px;background:var(--dark2);border:1px solid var(--border2);border-radius:var(--r);padding:10px 20px;font-size:13px;font-weight:700;transition:border-color .2s}
.partner:hover{border-color:rgba(255,255,255,.28)}
.p-dot{width:10px;height:10px;border-radius:50%;flex-shrink:0}
.p-cert{font-size:10px;font-weight:400;color:var(--gray);border-left:1px solid var(--border2);padding-left:10px;margin-left:4px}
.partner-badges{display:flex;align-items:center;gap:20px;margin-left:auto;flex-wrap:wrap}
.g-badge{height:78px;opacity:.9;transition:opacity .2s}
.g-badge:hover{opacity:1}
.m-badge{height:78px;width:auto;border-radius:10px;object-fit:contain;background:#fff;padding:8px;opacity:.9;transition:opacity .2s}
.m-badge:hover{opacity:1}

/* AVI STRIP */
.avi-strip{background:linear-gradient(135deg,#170000 0%,var(--dark2) 100%);border-left:4px solid var(--red);border-bottom:1px solid var(--border);padding:20px var(--gutter);display:flex;align-items:center;gap:20px;flex-wrap:wrap}
.avi-badge{background:var(--red);color:#fff;padding:5px 12px;border-radius:4px;font-size:10px;font-weight:800;letter-spacing:2px;text-transform:uppercase;white-space:nowrap;flex-shrink:0}
.avi-info{flex:1;min-width:200px}
.avi-title{font-size:17px;font-weight:800;color:var(--white);margin-bottom:3px}
.avi-sub{font-size:13px;font-weight:300;color:var(--gray)}
.avi-btn{background:rgba(181,13,13,.15);color:var(--red);border:1px solid rgba(181,13,13,.35);padding:10px 22px;border-radius:var(--r);font-size:12px;font-weight:700;text-transform:uppercase;letter-spacing:.8px;cursor:pointer;white-space:nowrap;transition:all .2s;display:inline-block}
.avi-btn:hover{background:var(--red);color:#fff}

/* SECTION */
.sec{padding:88px var(--gutter);border-bottom:1px solid var(--border)}
.sec-bg1{background:var(--black2)}
.sec-bg2{background:var(--dark)}

.eyebrow{display:flex;align-items:center;gap:10px;font-size:10px;font-weight:800;letter-spacing:3.5px;text-transform:uppercase;color:var(--red);margin-bottom:16px}
.eyebrow-line{width:26px;height:2px;background:var(--red);flex-shrink:0}
.sec-title{font-weight:900;font-size:clamp(30px,4.8vw,56px);line-height:.98;letter-spacing:-1.5px;text-transform:uppercase;color:var(--white);margin-bottom:12px}
.sec-sub{font-size:15px;font-weight:300;color:var(--gray);line-height:1.8;max-width:590px}

/* SERVICIOS */
.svc-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(215px,1fr));gap:2px;margin-top:52px}
.svc-card{background:var(--dark);border:1px solid var(--border);border-radius:4px;padding:30px 24px;cursor:pointer;position:relative;overflow:hidden;transition:background .2s,transform .2s,box-shadow .2s}
.svc-card::after{content:'';position:absolute;bottom:0;left:0;right:0;height:3px;background:var(--red);transform:scaleX(0);transform-origin:left;transition:transform .3s}
.svc-card:hover::after{transform:scaleX(1)}
.svc-card:hover{background:var(--dark2);transform:translateY(-3px);box-shadow:0 16px 48px rgba(0,0,0,.55)}
.svc-card.on{background:var(--red);border-color:var(--red);transform:translateY(-3px);box-shadow:0 16px 48px rgba(181,13,13,.35)}
.svc-card.on::after{display:none}
.svc-chk{position:absolute;top:13px;right:13px;width:22px;height:22px;background:rgba(255,255,255,.25);border-radius:50%;display:none;align-items:center;justify-content:center;font-size:12px;font-weight:800;color:#fff}
.svc-card.on .svc-chk{display:flex}
.svc-ico{font-size:28px;margin-bottom:16px;display:block;line-height:1}
.svc-name{font-weight:800;font-size:15px;text-transform:uppercase;letter-spacing:.8px;color:var(--white);margin-bottom:8px}
.svc-desc{font-size:12px;font-weight:400;color:var(--gray);line-height:1.65}
.svc-card.on .svc-desc{color:rgba(255,255,255,.75)}
.svc-pill{display:inline-block;margin-top:13px;background:rgba(255,255,255,.07);color:var(--gray);font-size:10px;font-weight:700;letter-spacing:1.5px;text-transform:uppercase;padding:4px 10px;border-radius:4px}
.svc-card.on .svc-pill{background:rgba(255,255,255,.2);color:#fff}

/* PLAN BOX */
.plan-box{border:1px solid var(--border);border-radius:var(--rl);overflow:hidden}
.plan-empty{background:var(--dark2);padding:66px 32px;text-align:center}
.plan-empty-ico{font-size:44px;margin-bottom:14px;display:block}
.plan-empty-t{font-weight:800;font-size:19px;text-transform:uppercase;letter-spacing:.5px;color:var(--white);margin-bottom:7px}
.plan-empty-s{font-size:14px;font-weight:300;color:var(--gray)}
.plan-fill{display:none}
.plan-fill.show{display:flex;flex-direction:column}
.plan-l{padding:46px;background:var(--dark);border-right:1px solid var(--border)}
.plan-ey{font-size:10px;font-weight:800;letter-spacing:3px;text-transform:uppercase;color:var(--red);margin-bottom:10px;display:flex;align-items:center;gap:8px}
.plan-name{font-weight:900;font-size:38px;text-transform:uppercase;letter-spacing:-.5px;color:var(--white);margin-bottom:28px;line-height:1.02}
.plan-inc-lbl{font-size:10px;font-weight:700;letter-spacing:2px;text-transform:uppercase;color:var(--gray2);margin-bottom:13px}
.plan-list{list-style:none}
.plan-list li{display:flex;align-items:flex-start;gap:12px;padding:13px 0;border-bottom:1px solid var(--border);font-size:14px;font-weight:400;color:rgba(255,255,255,.82)}
.plan-list li:last-child{border-bottom:none}
.plan-chk{flex-shrink:0;width:20px;height:20px;background:rgba(181,13,13,.2);border-radius:50%;display:flex;align-items:center;justify-content:center;color:var(--red);font-size:10px;font-weight:800;margin-top:2px}
.plan-r{padding:46px;background:var(--dark2);display:flex;flex-direction:column}
.plan-r-t{font-weight:800;font-size:18px;text-transform:uppercase;letter-spacing:.5px;color:var(--white);margin-bottom:9px}
.plan-r-s{font-size:13px;font-weight:300;color:var(--gray);line-height:1.7;margin-bottom:28px}
.btn-wa{width:100%;background:#25D366;color:#fff;border:none;padding:15px 20px;border-radius:var(--r);font-family:'Work Sans',sans-serif;font-size:14px;font-weight:800;text-transform:uppercase;letter-spacing:.8px;cursor:pointer;display:flex;align-items:center;justify-content:center;gap:10px;transition:background .2s,box-shadow .2s;margin-bottom:12px;text-decoration:none}
.btn-wa:hover{background:#1fba58;box-shadow:0 6px 24px rgba(37,211,102,.3)}
.btn-call{width:100%;background:rgba(255,255,255,.06);color:var(--white);border:1px solid var(--border2);padding:13px 20px;border-radius:var(--r);font-family:'Work Sans',sans-serif;font-size:13px;font-weight:700;text-transform:uppercase;letter-spacing:.8px;cursor:pointer;transition:background .2s;display:flex;align-items:center;justify-content:center;text-decoration:none}
.btn-call:hover{background:rgba(255,255,255,.1)}
.plan-trust{margin-top:auto;padding-top:26px;display:flex;flex-wrap:wrap;gap:12px}
.trust-it{display:flex;align-items:center;gap:6px;font-size:11px;font-weight:500;color:var(--gray2)}

/* CASOS */
.ctabs{display:flex;gap:4px;margin-bottom:36px;flex-wrap:wrap}
.ctab{padding:10px 22px;border-radius:var(--r);border:1px solid var(--border);font-size:12px;font-weight:700;text-transform:uppercase;letter-spacing:.8px;cursor:pointer;background:transparent;color:var(--gray);transition:all .2s}
.ctab:hover{border-color:var(--border2);color:var(--white)}
.ctab.on{background:var(--red);color:#fff;border-color:var(--red)}

.web-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(240px,1fr));gap:16px}
.web-card{background:var(--dark2);border:1px solid var(--border);border-radius:var(--rl);overflow:hidden;cursor:pointer;transition:transform .2s,border-color .2s,box-shadow .2s}
.web-card:hover{transform:translateY(-4px);border-color:rgba(181,13,13,.4);box-shadow:0 14px 44px rgba(0,0,0,.55)}
.web-thumb{height:140px;background:var(--dark3);display:flex;align-items:center;justify-content:center;font-size:46px;border-bottom:1px solid var(--border);position:relative;overflow:hidden}
.web-over{position:absolute;inset:0;background:rgba(181,13,13,.9);opacity:0;transition:opacity .2s;display:flex;align-items:center;justify-content:center;font-size:13px;font-weight:700;text-transform:uppercase;letter-spacing:1px;color:#fff}
.web-card:hover .web-over{opacity:1}
.web-body{padding:16px 18px}
.web-kw{font-size:10px;font-weight:600;color:var(--gray2);letter-spacing:1px;text-transform:uppercase;margin-bottom:4px}
.web-name{font-weight:800;font-size:15px;color:var(--white);margin-bottom:4px;line-height:1.2}
.web-domain{font-size:11px;font-weight:400;color:var(--gray);margin-bottom:8px}
.web-result{font-size:12px;font-weight:700;color:#25D366;display:flex;align-items:center;gap:5px}
.web-result::before{content:"↑"}

.ads-grid{display:grid;grid-template-columns:repeat(auto-fit,minmax(280px,1fr));gap:16px}
.ads-card{background:var(--dark2);border:1px solid var(--border);border-radius:var(--rl);padding:28px;transition:border-color .2s,transform .2s}
.ads-card:hover{border-color:rgba(181,13,13,.35);transform:translateY(-3px)}
.ads-plats{display:flex;gap:8px;margin-bottom:16px}
.ads-badge{padding:5px 12px;border-radius:4px;font-size:11px;font-weight:700}
.bg-g{background:rgba(66,133,244,.15);color:#6aa3f8}
.bg-m{background:rgba(24,119,242,.15);color:#5d9cf5}
.ads-biz{font-weight:800;font-size:20px;color:var(--white);margin-bottom:20px}
.ads-metrics{display:grid;grid-template-columns:repeat(2,1fr);gap:10px}
.ads-met{background:var(--dark);border-radius:var(--r);padding:14px;text-align:center;border:1px solid var(--border)}
.ads-val{font-weight:900;font-size:26px;color:var(--red);line-height:1}
.ads-lbl{font-size:11px;font-weight:400;color:var(--gray);margin-top:4px}

.avi-c-grid{display:grid;grid-template-columns:repeat(auto-fit,minmax(260px,1fr));gap:16px}
.avi-c{background:var(--dark2);border:1px solid var(--border);border-radius:var(--rl);padding:28px;transition:border-color .2s}
.avi-c:hover{border-color:rgba(181,13,13,.35)}
.avi-c-ico{font-size:32px;margin-bottom:12px}
.avi-c-name{font-weight:800;font-size:18px;color:var(--white);margin-bottom:9px}
.avi-c-desc{font-size:13px;font-weight:300;color:var(--gray);line-height:1.7;margin-bottom:13px}
.avi-c-r{font-size:13px;font-weight:700;color:#25D366;display:flex;align-items:center;gap:6px}
.avi-c-r::before{content:"↑"}
.vid-ph{background:var(--dark2);border:1px dashed var(--border2);border-radius:var(--rl);aspect-ratio:16/9;display:flex;flex-direction:column;align-items:center;justify-content:center;gap:14px;cursor:pointer;transition:border-color .2s,background .2s;text-align:center}
.vid-ph:hover{border-color:var(--red);background:rgba(181,13,13,.04)}
.play-btn{width:68px;height:68px;background:var(--red);border-radius:50%;display:flex;align-items:center;justify-content:center;transition:transform .2s,box-shadow .2s}
.vid-ph:hover .play-btn{transform:scale(1.07);box-shadow:0 0 30px rgba(181,13,13,.6)}
.play-tri{width:0;height:0;border-top:12px solid transparent;border-bottom:12px solid transparent;border-left:20px solid #fff;margin-left:5px}
.vid-lbl{font-size:12px;font-weight:700;color:var(--gray);text-transform:uppercase;letter-spacing:1.5px}

/* WEB SCROLL CARDS */
.web-scroll-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(220px,1fr));gap:18px}
.web-scroll-card{background:var(--dark2);border:1px solid var(--border);border-radius:var(--rl);overflow:hidden;transition:transform .2s,border-color .2s,box-shadow .2s}
.web-scroll-card:hover{transform:translateY(-4px);border-color:rgba(181,13,13,.4);box-shadow:0 14px 44px rgba(0,0,0,.55)}
.web-scroll-window{height:220px;overflow:hidden;position:relative;cursor:pointer}
.web-scroll-img{width:100%;display:block;transition:transform 8s ease;transform:translateY(0)}
.web-scroll-window:hover .web-scroll-img{transform:translateY(calc(-100% + 220px))}
.web-scroll-overlay{position:absolute;inset:0;background:rgba(181,13,13,.0);transition:background .3s;display:flex;align-items:center;justify-content:center;opacity:0;transition:opacity .3s}
.web-scroll-window:hover .web-scroll-overlay{opacity:1;background:rgba(0,0,0,.15)}
.web-scroll-footer{padding:14px 16px;display:flex;align-items:center;justify-content:space-between;border-top:1px solid var(--border)}
.web-scroll-name{font-size:12px;font-weight:700;color:var(--white);white-space:nowrap;overflow:hidden;text-overflow:ellipsis;max-width:130px}
.web-scroll-btn{background:var(--red);color:#fff;padding:6px 14px;border-radius:4px;font-size:10px;font-weight:800;text-transform:uppercase;letter-spacing:.8px;white-space:nowrap;flex-shrink:0;transition:background .2s;display:inline-block;text-decoration:none}
.web-scroll-btn:hover{background:var(--red2)}

/* SEO CARDS */
.seo-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(260px,1fr));gap:16px}
.seo-card{background:var(--dark2);border:1px solid var(--border);border-radius:var(--rl);padding:26px;transition:border-color .2s,transform .2s}
.seo-card:hover{border-color:rgba(181,13,13,.4);transform:translateY(-3px)}
.seo-rank{font-size:11px;font-weight:800;letter-spacing:2px;text-transform:uppercase;color:var(--red);margin-bottom:8px}
.seo-kw{font-weight:900;font-size:20px;color:var(--white);margin-bottom:4px}
.seo-domain{font-size:12px;font-weight:400;color:var(--gray);margin-bottom:18px}
.seo-btn{display:inline-block;background:rgba(66,133,244,.15);color:#6aa3f8;border:1px solid rgba(66,133,244,.25);padding:8px 18px;border-radius:4px;font-size:11px;font-weight:700;text-transform:uppercase;letter-spacing:.8px;transition:background .2s;text-decoration:none}
.seo-btn:hover{background:rgba(66,133,244,.3)}

/* ADS IMAGE CARDS */
.ads-img-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(220px,1fr));gap:16px}
.ads-img-card{background:var(--dark2);border:1px solid var(--border);border-radius:var(--rl);overflow:hidden;transition:transform .2s,border-color .2s,box-shadow .2s}
.ads-img-card:hover{transform:translateY(-4px);border-color:rgba(181,13,13,.4);box-shadow:0 14px 44px rgba(0,0,0,.55)}
.ads-img-card img{width:100%;height:auto;display:block;cursor:zoom-in}

/* LIGHTBOX */
.lightbox{position:fixed;inset:0;z-index:2000;background:rgba(0,0,0,.92);display:none;align-items:center;justify-content:center;padding:40px;cursor:zoom-out;backdrop-filter:blur(4px)}
.lightbox.show{display:flex}
.lightbox img{max-width:100%;max-height:100%;width:auto;height:auto;border-radius:8px;box-shadow:0 24px 90px rgba(0,0,0,.75);cursor:default}
.lightbox-close{position:absolute;top:20px;right:30px;font-size:44px;line-height:1;color:#fff;cursor:pointer;font-weight:300;transition:color .2s}
.lightbox-close:hover{color:var(--red)}

/* AVI IMAGE CARDS */
.avi-img-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(200px,1fr));gap:16px}
.avi-img-card{background:var(--dark2);border:1px solid var(--border);border-radius:var(--rl);overflow:hidden;transition:transform .2s,border-color .2s,box-shadow .2s;display:flex;flex-direction:column}
.avi-img-card:hover{transform:translateY(-4px);border-color:rgba(181,13,13,.4);box-shadow:0 14px 44px rgba(0,0,0,.55)}
.avi-img-logo{height:120px;display:flex;align-items:center;justify-content:center;overflow:hidden;background:#fff;padding:16px}
.avi-img-logo img{max-height:90px;max-width:100%;object-fit:contain;display:block}
.avi-img-footer{padding:14px 16px;text-align:center;border-top:1px solid var(--border)}
.avi-wpp-btn{display:inline-block;background:#25D366;color:#fff;padding:8px 18px;border-radius:4px;font-size:11px;font-weight:800;text-transform:uppercase;letter-spacing:.8px;transition:background .2s;text-decoration:none}
.avi-wpp-btn:hover{background:#1fba58}

/* CERTIFIED SECTION */
.certified-sec{position:relative;padding:72px var(--gutter);background:var(--dark);border-bottom:1px solid var(--border);overflow:hidden}
.certified-grid{position:relative;z-index:1;display:grid;grid-template-columns:1fr auto;gap:52px;align-items:center}
.certified-inner{max-width:860px}
.certified-badges{display:flex;align-items:center;gap:28px;flex-wrap:wrap;margin-top:28px}
.certified-badges img{height:112px;width:auto}
.certified-world{width:min(360px,30vw);height:auto;filter:drop-shadow(0 0 45px rgba(181,13,13,.4));animation:world-float 6s ease-in-out infinite}
@media(max-width:960px){.certified-grid{grid-template-columns:1fr;justify-items:center;text-align:center}.certified-world{width:240px}.certified-badges{justify-content:center}}

/* INDEPENDENT SERVICES SECTION */
.ind-sec{padding:72px var(--gutter);background:var(--black2);border-bottom:1px solid var(--border)}
.ind-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(300px,1fr));gap:16px;margin-top:40px}
.ind-card{background:var(--dark);border:1px solid var(--border2);border-radius:var(--rl);padding:34px;transition:border-color .2s,transform .2s}
.ind-card:hover{border-color:rgba(181,13,13,.4);transform:translateY(-3px)}
.ind-ico{font-size:36px;margin-bottom:16px;display:block}
.ind-name{font-weight:900;font-size:22px;text-transform:uppercase;letter-spacing:-.3px;color:var(--white);margin-bottom:10px}
.ind-desc{font-size:13px;font-weight:300;color:var(--white);line-height:1.75;margin-bottom:20px}
.ind-pill{display:inline-block;background:rgba(181,13,13,.12);color:var(--red);border:1px solid rgba(181,13,13,.25);font-size:10px;font-weight:700;letter-spacing:1.5px;text-transform:uppercase;padding:5px 12px;border-radius:4px}

/* IND LAYOUT + TECH STACK */
.ind-layout{display:grid;grid-template-columns:1fr 360px;gap:32px;align-items:start;margin-top:40px}
.ind-layout .ind-grid{margin-top:0;grid-template-columns:1fr}
.tech-panel{background:var(--dark);border:1px solid var(--border2);border-radius:var(--rl);padding:30px;position:sticky;top:90px}
.tech-title{font-size:11px;font-weight:800;letter-spacing:2px;text-transform:uppercase;color:var(--red);margin-bottom:22px;display:flex;align-items:center;gap:8px}
.tech-title::before{content:"";width:22px;height:2px;background:var(--red);flex-shrink:0}
.tech-grid{display:grid;grid-template-columns:repeat(2,1fr);gap:10px}
.tech-chip{display:flex;align-items:center;gap:10px;background:var(--dark2);border:1px solid var(--border);border-radius:var(--r);padding:11px 13px;transition:border-color .2s,transform .15s}
.tech-chip:hover{border-color:rgba(181,13,13,.4);transform:translateY(-2px)}
.tech-chip img{width:22px;height:22px;object-fit:contain;flex-shrink:0}
.tech-chip span{font-size:12px;font-weight:600;color:var(--white);white-space:nowrap;overflow:hidden;text-overflow:ellipsis}
.tech-chip.wide{grid-column:1/-1}
@media(max-width:1080px){.ind-layout{grid-template-columns:1fr}.tech-panel{position:static}}
@media(max-width:540px){.tech-grid{grid-template-columns:1fr}}

/* PRESENCIA MUNDIAL */
.world-sec{position:relative;background:var(--black2);border-bottom:1px solid var(--border);padding:96px var(--gutter);overflow:hidden}
.world-glow{position:absolute;top:50%;right:-6%;transform:translateY(-50%);width:62%;height:130%;background:radial-gradient(ellipse at center,rgba(181,13,13,.16) 0%,transparent 62%);pointer-events:none}
.world-inner{position:relative;z-index:1;display:grid;grid-template-columns:1fr 1.1fr;gap:52px;align-items:center}
.world-text{max-width:480px}
.world-text .sec-sub{margin-bottom:30px}
.world-img-wrap{display:flex;justify-content:center;align-items:center}
.world-img{width:100%;max-width:600px;height:auto;filter:drop-shadow(0 0 60px rgba(181,13,13,.4));animation:world-float 6s ease-in-out infinite}
@keyframes world-float{0%,100%{transform:translateY(0)}50%{transform:translateY(-16px)}}
@media(max-width:960px){
  .world-sec{padding:58px 20px}
  .world-inner{grid-template-columns:1fr;gap:34px;text-align:center}
  .world-text{max-width:none}
  .world-text .eyebrow{justify-content:center}
  .world-img{max-width:420px}
}

/* COMBO LAYOUT FIX — services left, cart right */
.combo-layout{display:grid;grid-template-columns:1fr 380px;gap:32px;align-items:start}
@media(max-width:1080px){.combo-layout{grid-template-columns:1fr}}
.combo-sticky{position:sticky;top:90px}

/* MOBILE */
@media(max-width:960px){
  .nav{padding:0 20px}.nav-links{display:none}
  .hero{padding:108px 20px 78px}.hero-vline{display:none}.hero h1{font-size:52px}
  .stats{grid-template-columns:repeat(3,1fr)}
  .stat:nth-child(3){border-right:none}
  .stat:nth-child(4),.stat:nth-child(5){border-top:1px solid var(--border)}
  .partners{padding:18px 20px;gap:16px}.partners-sep{display:none}
  .avi-strip{padding:18px 20px}.sec{padding:58px 20px}
  .plan-fill.show{grid-template-columns:1fr}.plan-r{border-top:1px solid var(--border)}
  .footer-top{grid-template-columns:1fr 1fr;gap:30px}footer{padding:44px 20px 24px}
}
@media(max-width:540px){
  .stats{grid-template-columns:repeat(2,1fr)}
  .stat:nth-child(3){border-right:1px solid var(--border);border-top:1px solid var(--border)}
  .stat:nth-child(4){border-top:1px solid var(--border);border-right:none}
  .stat:nth-child(5){grid-column:1/-1}
  .footer-top{grid-template-columns:1fr}
}
</style>

    
<!-- HERO -->
<section class="hero" id="inicio">
  <div class="hero-glow"></div>
  <div class="hero-vline"></div>
  <img class="hero-logobg" src="https://dimark.co/wp-content/uploads/2025/07/mapmundi.png" alt="">

  <div class="hero-tag">
    <span class="hero-tag-line"></span>
    Agencia Digital · Medellín · LATAM · USA
  </div>

  <h1>
    Hacemos crecer
    <span class="h1-red">tu negocio</span>
    <span class="h1-ghost">digitalmente</span>
  </h1>

  <p class="hero-desc">
    <b>+10 años</b> convirtiendo inversión digital en resultados medibles.<br>
    Google Ads · Meta Ads · SEO · Diseño Web · Automatización con IA.
  </p>

  <div class="hero-btns">
    <a href="#planes" class="btn-red">Elegir mi plan →</a>
    <a href="#casos" class="btn-ghost">Ver casos de éxito</a>
  </div>

  <div class="hero-scroll">
    <span class="hero-scroll-line"></span>
    Scroll para explorar
  </div>
</section>

<!-- STATS -->
<div class="stats">
  <div class="stat"><div class="stat-n"><span class="acc">+</span>10</div><div class="stat-l">Años de<br>experiencia</div></div>
  <div class="stat"><div class="stat-n"><span class="acc">+</span>200</div><div class="stat-l">Sitios web<br>creados</div></div>
  <div class="stat"><div class="stat-n"><span class="acc">+</span>500</div><div class="stat-l">Keywords en<br>primeros puestos</div></div>
  <div class="stat"><div class="stat-n" style="font-size:26px;letter-spacing:0">LATAM<span class="acc"> + </span>USA</div><div class="stat-l">Presencia<br>internacional</div></div>
  <div class="stat"><div class="stat-n" style="font-size:28px;color:var(--red)">AVI IA</div><div class="stat-l">Asistente propio<br>con inteligencia artificial</div></div>
</div>

<!-- PARTNERS -->
<div class="partners">
  <span class="partners-lbl">Partners certificados</span>
  <div class="partners-sep"></div>
  <div class="partner-row">
    <div class="partner"><span class="p-dot" style="background:#4285F4"></span>Google Ads<small class="p-cert">Partner oficial</small></div>
    <div class="partner"><span class="p-dot" style="background:#1877F2"></span>Meta Ads<small class="p-cert">Partner oficial</small></div>
  </div>
  <div class="partner-badges">
    <a href="https://www.google.com/partners/agency?id=2597029018" target="_blank">
      <img class="g-badge" src="https://www.gstatic.com/partners/badge/images/2025/PartnerBadgeClickable.svg" alt="Google Partner">
    </a>
    <img class="m-badge" src="https://dimark.co/wp-content/uploads/2026/01/WhatsApp-Image-2026-01-13-at-9.39.34-AM.jpeg" alt="Meta Business Partner">
  </div>
</div>

<!-- AVI STRIP -->
<div class="avi-strip">
  <div class="avi-badge">Nuevo</div>
  <div class="avi-info">
    <div class="avi-title">🤖 Somos los creadores de AVI Asistente</div>
    <div class="avi-sub">Automatización inteligente con IA para transformar los procesos de tu empresa las 24 horas</div>
  </div>
  <a href="https://dimark.co/desarrollos-propios/" target="_blank" class="avi-btn">Conocer AVI →</a>
</div>

<!-- PRESENCIA MUNDIAL -->
<section class="world-sec" id="presencia">
  <div class="world-glow"></div>
  <div class="world-inner">
    <div class="world-text">
      <div class="eyebrow"><span class="eyebrow-line"></span>Presencia internacional</div>
      <h2 class="sec-title">Con presencia<br>a nivel mundial</h2>
      <p class="sec-sub">Acompañamos el crecimiento digital de empresas en LATAM y USA. Donde esté tu negocio, estamos listos para hacerlo crecer.</p>
      <a href="https://dimark.co/contactenos/" target="_blank" class="btn-red">Contáctenos →</a>
    </div>
    <div class="world-img-wrap">
      <img class="world-img" src="https://dimark.co/wp-content/uploads/2025/07/mapmundi.png" alt="Mapa mundial de presencia Dimark — LATAM y USA" loading="lazy">
    </div>
  </div>
</section>

<!-- SERVICIOS + PLANES COMBO -->
<section class="sec sec-bg1" id="servicios" style="padding-bottom:0;border-bottom:none">
  <div style="max-width:640px">
    <div class="eyebrow"><span class="eyebrow-line"></span>Lo que hacemos</div>
    <h2 class="sec-title">Servicios que<br>generan resultados</h2>
    <p class="sec-sub">Selecciona los que tu negocio necesita y armamos el combo ideal para ti — al instante.</p>
  </div>
</section>

<section class="sec sec-bg1" id="planes" style="padding-top:28px;border-top:none">
  <div class="combo-layout">
    <!-- LEFT: services grid -->
    <div>
      <div class="svc-grid" id="svcGrid">
        <div class="svc-card" data-s="google"><div class="svc-chk">✓</div><span class="svc-ico">🔍</span><div class="svc-name">Google Ads</div><div class="svc-desc">Campañas SEM de alto rendimiento con máximo retorno de inversión en buscadores</div><span class="svc-pill">SEM / PPC</span></div>
        <div class="svc-card" data-s="meta"><div class="svc-chk">✓</div><span class="svc-ico">📣</span><div class="svc-name">Meta Ads</div><div class="svc-desc">Publicidad en Facebook e Instagram con segmentación precisa y alta conversión</div><span class="svc-pill">Redes sociales</span></div>
        <div class="svc-card" data-s="ugc"><div class="svc-chk">✓</div><span class="svc-ico">🎥</span><div class="svc-name">UGC Videos</div><div class="svc-desc">Contenido de video auténtico y nativo para maximizar el rendimiento de tus anuncios</div><span class="svc-pill">2 videos / mes</span></div>
        <div class="svc-card" data-s="web"><div class="svc-chk">✓</div><span class="svc-ico">🌐</span><div class="svc-name">Diseño Web</div><div class="svc-desc">Landing pages y sitios web diseñados para convertir visitantes en clientes</div><span class="svc-pill">Conversión</span></div>
        <div class="svc-card" data-s="seo"><div class="svc-chk">✓</div><span class="svc-ico">📈</span><div class="svc-name">SEO</div><div class="svc-desc">Posicionamiento orgánico sostenible en primeras posiciones de Google</div><span class="svc-pill">Orgánico</span></div>
        <div class="svc-card" data-s="avi"><div class="svc-chk">✓</div><span class="svc-ico">🤖</span><div class="svc-name">AVI Asistente</div><div class="svc-desc">Nuestro asistente de IA propio para automatizar ventas y atención 24/7</div><span class="svc-pill">IA propia</span></div>
      </div>
    </div>
    <!-- RIGHT: plan cart -->
    <div class="combo-sticky">
      <div style="margin-bottom:16px">
        <div class="eyebrow"><span class="eyebrow-line"></span>Elige tu plan</div>
        <h2 class="sec-title" style="font-size:clamp(22px,3vw,36px)">Tu combo<br>a la medida</h2>
        <p class="sec-sub" style="font-size:13px">Selecciona los servicios y al instante te mostramos el plan ideal.</p>
      </div>
      <div class="plan-box">
        <div class="plan-empty" id="planEmpty">
          <span class="plan-empty-ico">☝️</span>
          <div class="plan-empty-t">Selecciona tus servicios</div>
          <div class="plan-empty-s">Haz clic en las tarjetas de servicios para ver tu plan ideal al instante</div>
        </div>
        <div class="plan-fill" id="planFill">
          <div class="plan-l">
            <div class="plan-ey" id="planEy">Plan recomendado</div>
            <div class="plan-name" id="planName" style="font-size:28px">—</div>
            <div class="plan-inc-lbl">Incluye</div>
            <ul class="plan-list" id="planList"></ul>
          </div>
          <div class="plan-r" style="border-top:1px solid var(--border)">
            <div class="plan-r-t">¿Te interesa este plan?</div>
            <div class="plan-r-s">Habla ahora mismo con uno de nuestros expertos y recibe una propuesta personalizada sin ningún compromiso.</div>
            <a href="#" class="btn-wa" id="planWA" target="_blank">
              <svg width="20" height="20" viewBox="0 0 24 24" fill="white"><path d="M17.472 14.382c-.297-.149-1.758-.867-2.03-.967-.273-.099-.471-.148-.67.15-.197.297-.767.966-.94 1.164-.173.199-.347.223-.644.075-.297-.15-1.255-.463-2.39-1.475-.883-.788-1.48-1.761-1.653-2.059-.173-.297-.018-.458.13-.606.134-.133.298-.347.446-.52.149-.174.198-.298.298-.497.099-.198.05-.371-.025-.52-.075-.149-.669-1.612-.916-2.207-.242-.579-.487-.5-.669-.51-.173-.008-.371-.01-.57-.01-.198 0-.52.074-.792.372-.272.297-1.04 1.016-1.04 2.479 0 1.462 1.065 2.875 1.213 3.074.149.198 2.096 3.2 5.077 4.487.709.306 1.262.489 1.694.625.712.227 1.36.195 1.871.118.571-.085 1.758-.719 2.006-1.413.248-.694.248-1.289.173-1.413-.074-.124-.272-.198-.57-.347z"/><path d="M12 0C5.373 0 0 5.373 0 12c0 2.124.554 4.118 1.523 5.845L0 24l6.337-1.507A11.95 11.95 0 0012 24c6.627 0 12-5.373 12-12S18.627 0 12 0zm0 21.818a9.808 9.808 0 01-5.034-1.384l-.36-.214-3.733.888.917-3.63-.235-.374A9.797 9.797 0 012.182 12C2.182 6.589 6.589 2.182 12 2.182S21.818 6.589 21.818 12 17.411 21.818 12 21.818z"/></svg>
              Contactar por WhatsApp
            </a>
            <a href="tel:+573203920599" class="btn-call">📞 Llamar: 320 392 05 99</a>
            <div class="plan-trust">
              <div class="trust-it">⚡ Respuesta &lt;30 min</div>
              <div class="trust-it">🎯 Asesoría gratis</div>
              <div class="trust-it">🔒 Sin compromiso</div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</section>

<!-- CASOS -->
<section class="sec sec-bg1" id="casos">
  <div style="max-width:640px;margin-bottom:40px">
    <div class="eyebrow"><span class="eyebrow-line"></span>Resultados reales</div>
    <h2 class="sec-title">Casos de éxito</h2>
    <p class="sec-sub">Empresas que apostaron por Dimark y transformaron su crecimiento digital.</p>
  </div>
  <div class="ctabs">
    <div class="ctab on" data-cat="web">🌐 Sitios web</div>
    <div class="ctab" data-cat="seo">📈 SEO</div>
    <div class="ctab" data-cat="google-ads">🔍 Google Ads</div>
    <div class="ctab" data-cat="meta-ads">📣 Meta Ads</div>
    <div class="ctab" data-cat="avi">🤖 AVI Asistente</div>
  </div>
  <div id="casosContent"></div>
</section>

<!-- CERTIFIED SECTION -->
<section class="certified-sec" id="certificados">
  <div class="certified-grid">
  <div class="certified-inner">
    <div class="eyebrow"><span class="eyebrow-line"></span>Certificaciones oficiales</div>
    <h2 class="sec-title" style="margin-bottom:16px">Agencia certificada en<br>Google Ads y Meta Ads</h2>
    <p class="sec-sub" style="max-width:780px">Somos partners certificados de Google Ads y Meta Ads, lo que respalda nuestro conocimiento técnico y estratégico en la gestión de campañas publicitarias digitales. Estas certificaciones oficiales garantizan que trabajamos bajo las mejores prácticas de ambas plataformas, con profesionales validados, acceso a programas de partners, formación continua y estándares de calidad exigidos por Google y Meta.</p>
    <div class="certified-badges">
      <img src="https://dimark.co/wp-content/uploads/2026/01/WhatsApp-Image-2026-01-13-at-9.39.34-AM.jpeg" alt="Meta Partner" style="height:112px;width:auto;border-radius:8px;object-fit:contain;background:#fff;padding:6px">
      <a href="https://www.google.com/partners/agency?id=2597029018" target="_blank">
        <img src="https://www.gstatic.com/partners/badge/images/2025/PartnerBadgeClickable.svg" alt="Google Partner Badge" style="height:112px;width:auto"/>
      </a>
    </div>
  </div>
  <img class="certified-world" src="https://dimark.co/wp-content/uploads/2025/07/mapmundi.png" alt="Presencia mundial Dimark" loading="lazy">
  </div>
</section>

<!-- INDEPENDENT SERVICES SECTION -->
<section class="ind-sec" id="servicios-independientes">
  <div style="max-width:640px">
    <div class="eyebrow"><span class="eyebrow-line"></span>Servicios personalizados</div>
    <h2 class="sec-title">Soluciones a medida<br>para tu negocio</h2>
    <p class="sec-sub">Servicios independientes desarrollados especialmente para proyectos que requieren una solución única y personalizada.</p>
  </div>
  <div class="ind-layout">
    <div class="ind-grid">
      <div class="ind-card">
        <span class="ind-ico">💻</span>
        <div class="ind-name">Software a la Medida</div>
        <div class="ind-desc">Desarrollamos plataformas internas, sistemas de gestión, herramientas empresariales e integraciones personalizadas según las necesidades específicas de tu negocio. Precio: según el proyecto.</div>
        <span class="ind-pill">Desarrollo personalizado</span>
      </div>
      <div class="ind-card">
        <span class="ind-ico">⚡</span>
        <div class="ind-name">Automatizaciones IA</div>
        <div class="ind-desc">Optimizamos procesos internos con herramientas de inteligencia artificial, integramos soluciones IA y mejoramos los flujos de trabajo de tu empresa para que trabaje sola. Precio: según el proyecto.</div>
        <span class="ind-pill">Inteligencia artificial</span>
      </div>
    </div>
    <aside class="tech-panel">
      <div class="tech-title">Tecnologías implementadas</div>
      <div class="tech-grid">
        <div class="tech-chip"><img src="https://cdn.simpleicons.org/openai/ffffff" alt="OpenAI" loading="lazy" onerror="this.style.display='none'"><span>OpenAI</span></div>
        <div class="tech-chip"><img src="https://cdn.simpleicons.org/claude/ffffff" alt="Claude" loading="lazy" onerror="this.style.display='none'"><span>Claude</span></div>
        <div class="tech-chip"><img src="https://cdn.simpleicons.org/googlegemini/ffffff" alt="Gemini" loading="lazy" onerror="this.style.display='none'"><span>Gemini</span></div>
        <div class="tech-chip"><img src="https://cdn.simpleicons.org/python/ffffff" alt="Python" loading="lazy" onerror="this.style.display='none'"><span>Python</span></div>
        <div class="tech-chip"><img src="https://cdn.simpleicons.org/javascript/ffffff" alt="JavaScript" loading="lazy" onerror="this.style.display='none'"><span>JavaScript</span></div>
        <div class="tech-chip"><img src="https://cdn.simpleicons.org/react/ffffff" alt="React" loading="lazy" onerror="this.style.display='none'"><span>React</span></div>
        <div class="tech-chip"><img src="https://cdn.simpleicons.org/amazonwebservices/ffffff" alt="AWS" loading="lazy" onerror="this.style.display='none'"><span>AWS</span></div>
        <div class="tech-chip"><img src="https://cdn.simpleicons.org/php/ffffff" alt="PHP" loading="lazy" onerror="this.style.display='none'"><span>PHP</span></div>
        <div class="tech-chip"><img src="https://cdn.simpleicons.org/nodedotjs/ffffff" alt="Node.js" loading="lazy" onerror="this.style.display='none'"><span>Node.js</span></div>
        <div class="tech-chip wide"><img src="https://cdn.simpleicons.org/whatsapp/ffffff" alt="WhatsApp Business API" loading="lazy" onerror="this.style.display='none'"><span>WhatsApp Business API</span></div>
      </div>
    </aside>
  </div>
</section>



<!-- LIGHTBOX -->
<div class="lightbox" id="lightbox">
  <span class="lightbox-close" id="lightboxClose">&times;</span>
  <img id="lightboxImg" src="" alt="Vista detallada del caso">
</div>

<script>
const CASOS={
  web:[
    {img:"https://dimark.co/wp-content/uploads/2026/02/screencapture-urgemiami-2026-02-13-16_54_37-scaled.png",name:"urgemiami.com",link:"https://urgemiami.com/"},
    {img:"https://dimark.co/wp-content/uploads/2026/01/screencapture-catherinepsicologa-2026-01-26-17_22_26-scaled.png",name:"catherinepsicologa.com",link:"https://catherinepsicologa.com/"},
    {img:"https://dimark.co/wp-content/uploads/2025/06/screencapture-ellas-co-2025-06-2-scaled.png",name:"ellas.com.co",link:"https://ellas.com.co/"},
    {img:"https://dimark.co/wp-content/uploads/2026/04/screencapture-drakonnyaldana-co-2026-04-07-09_26_19-scaled.png",name:"drakonnyaldana.co",link:"https://www.drakonnyaldana.co/"},
    {img:"https://dimark.co/wp-content/uploads/2025/07/screencapture-doctorsebastiansierra-2025-07-03-17_54_03-scaled.png",name:"doctorsebastiansierra.com",link:"https://doctorsebastiansierra.com/"},
    {img:"https://dimark.co/wp-content/uploads/2024/07/BeSmilet.png",name:"besmilet.com",link:"https://besmilet.com/"},
    {img:"https://dimark.co/wp-content/uploads/2025/01/screencapture-mccgloballogistics-2025-01-22-12_14_50-min.png",name:"mccgloballogistics.com",link:"https://mccgloballogistics.com/"},
    {img:"https://dimark.co/wp-content/uploads/2026/05/screencapture-dratatianavasquez-2026-05-05-12_42_18-scaled.png",name:"dratatianavasquez.com",link:"http://www.dratatianavasquez.com/"},
    {img:"https://dimark.co/wp-content/uploads/2025/06/screencapture-produsa-co-2025-06-26-16_29_07-min-scaled.png",name:"produsa.com.co",link:"https://produsa.com.co/"},
    {img:"https://dimark.co/wp-content/uploads/2024/07/screencapture-biogroup-co-2024-05-27-14_42_57-min-3.png",name:"biogroup.com.co",link:"https://www.biogroup.com.co/"},
  ],
  seo:[
    {kw:"Events casino florida",domain:"casinoeventsofflorida.com",link:"https://www.google.com/search?q=events+casino+florida"},
    {kw:"Software veterinario",domain:"okvet.co",link:"https://www.google.com/search?q=software+veterinario"},
    {kw:"Moteles oriente antioqueño",domain:"veronamotel.com",link:"https://www.google.com/search?q=moteles+oriente+antioque%C3%B1o"},
  ],
  googleAds:[
    "https://dimark.co/wp-content/uploads/2026/06/WhatsApp-Image-2026-06-02-at-4.46.53-PM-3.jpeg",
    "https://dimark.co/wp-content/uploads/2026/06/WhatsApp-Image-2026-06-02-at-4.46.53-PM-2.jpeg",
    "https://dimark.co/wp-content/uploads/2026/06/WhatsApp-Image-2026-06-02-at-4.46.53-PM-1.jpeg",
    "https://dimark.co/wp-content/uploads/2026/06/WhatsApp-Image-2026-06-02-at-4.46.53-PM.jpeg",
    "https://dimark.co/wp-content/uploads/2026/06/WhatsApp-Image-2026-06-02-at-4.46.52-PM.jpeg",
  ],
  metaAds:[
    "https://dimark.co/wp-content/uploads/2026/06/WhatsApp-Image-2026-06-02-at-4.46.54-PM-1.jpeg",
    "https://dimark.co/wp-content/uploads/2026/06/WhatsApp-Image-2026-06-02-at-4.46.54-PM.jpeg",
  ],
  avi:[
    {img:"https://dimark.co/wp-content/uploads/2026/06/logo_fondo_negro.jpg",wpp:"+573145833958"},
    {img:"https://dimark.co/wp-content/uploads/2026/06/Sin-titulo-1.png",wpp:"+573156043410"},
    {img:"https://dimark.co/wp-content/uploads/2026/06/file.jpg",wpp:"+50768330572"},
    {img:"https://dimark.co/wp-content/uploads/2026/06/file.png",wpp:"+573184840044"},
    {img:"https://dimark.co/wp-content/uploads/2026/06/logo-niido.png.webp",wpp:"+573102100381"},
    {img:"https://dimark.co/wp-content/uploads/2026/06/file-1.png",wpp:"+573216092116"},
    {img:"https://dimark.co/wp-content/uploads/2026/06/129146179f9b15b5fa-1.png",wpp:"+573043108503"},
  ]
};
const PLANS=[
  {ey:"Plan más completo 🏆",name:"PLAN PROFESIONAL",items:["Meta Ads + Google Ads","2 videos UGC mensuales","Landing page optimizada","AVI Asistente plan desafiante","SEO avanzado"],m:s=>s.has("google")&&s.has("meta")&&s.has("ugc")&&s.has("web")&&s.has("seo")&&s.has("avi")&&!s.has("software")&&!s.has("ia")},
  {ey:"Plan Plus ⭐",name:"PLAN PREMIUM PLUS",items:["Meta Ads + Google Ads","2 videos UGC mensuales","Landing page optimizada","AVI Asistente plan desafiante"],m:s=>s.has("google")&&s.has("meta")&&s.has("ugc")&&s.has("web")&&!s.has("seo")&&s.has("avi")&&!s.has("software")&&!s.has("ia")},
  {ey:"Plan Plus",name:"PLAN AVANZADO PLUS",items:["Meta Ads + Google Ads","2 videos UGC mensuales","Landing page nueva al mes optimizada"],m:s=>s.has("google")&&s.has("meta")&&s.has("ugc")&&s.has("web")&&!s.has("seo")&&!s.has("avi")&&!s.has("software")&&!s.has("ia")},
  {ey:"Plan Plus",name:"PLAN MEDIO PLUS",items:["Meta Ads + Google Ads","2 videos UGC mensuales"],m:s=>s.has("google")&&s.has("meta")&&s.has("ugc")&&!s.has("web")&&!s.has("seo")&&!s.has("avi")&&!s.has("software")&&!s.has("ia")},
  {ey:"Muy popular ⭐",name:"PLAN PREMIUM",items:["Meta Ads o Google Ads","2 videos UGC mensuales","Landing page optimizada","AVI Asistente plan desafiante"],m:s=>(s.has("google")!==s.has("meta"))&&s.has("ugc")&&s.has("web")&&!s.has("seo")&&s.has("avi")&&!s.has("software")&&!s.has("ia")},
  {ey:"Recomendado",name:"PLAN AVANZADO",items:["Meta Ads o Google Ads","2 videos UGC mensuales","Landing page nueva al mes optimizada"],m:s=>(s.has("google")!==s.has("meta"))&&s.has("ugc")&&s.has("web")&&!s.has("seo")&&!s.has("avi")&&!s.has("software")&&!s.has("ia")},
  {ey:"Ideal para crecer",name:"PLAN MEDIO",items:["Meta Ads o Google Ads","2 videos UGC mensuales"],m:s=>(s.has("google")!==s.has("meta"))&&s.has("ugc")&&!s.has("web")&&!s.has("seo")&&!s.has("avi")&&!s.has("software")&&!s.has("ia")},
  {ey:"Ideal para empezar",name:"PLAN EMPRENDEDOR",items:["Meta Ads o Google Ads (tu eliges)"],m:s=>(s.has("google")||s.has("meta"))&&!s.has("ugc")&&!s.has("web")&&!s.has("seo")&&!s.has("avi")&&!s.has("software")&&!s.has("ia")&&!(s.has("google")&&s.has("meta"))},
  {ey:"Precio personalizado",name:"SOFTWARE A LA MEDIDA",items:["Plataformas internas personalizadas","Sistemas de gestión","Herramientas empresariales","Integraciones","Precio: según el proyecto"],m:s=>s.has("software")&&!s.has("ia")},
  {ey:"Precio personalizado",name:"AUTOMATIZACIÓN CON IA",items:["Optimización de procesos con IA","Integración herramientas IA","Mejoramiento de flujos","Precio: según el proyecto"],m:s=>s.has("ia")&&!s.has("software")},
  {ey:"Solución enterprise",name:"IA + SOFTWARE A MEDIDA",items:["Desarrollo de software personalizado","Automatización de procesos con IA","Precio: según el proyecto"],m:s=>s.has("ia")&&s.has("software")},
];
const sel=new Set();
document.querySelectorAll(".svc-card").forEach(c=>{
  c.addEventListener("click",()=>{
    const s=c.dataset.s;
    sel.has(s)?(sel.delete(s),c.classList.remove("on")):(sel.add(s),c.classList.add("on"));
    upPlan();
  });
});
function upPlan(){
  const emp=document.getElementById("planEmpty"),fill=document.getElementById("planFill");
  if(!sel.size){emp.style.display="block";fill.classList.remove("show");return;}
  let p=PLANS.find(x=>x.m(sel));
  if(!p){
    const it=[];
    if(sel.has("google")&&sel.has("meta"))it.push("Meta Ads + Google Ads");
    else if(sel.has("google"))it.push("Google Ads");
    else if(sel.has("meta"))it.push("Meta Ads");
    if(sel.has("ugc"))it.push("2 videos UGC mensuales");
    if(sel.has("web"))it.push("Landing page optimizada");
    if(sel.has("avi"))it.push("AVI Asistente plan desafiante");
    if(sel.has("seo"))it.push("SEO avanzado");
    if(sel.has("software"))it.push("Software a la medida");
    if(sel.has("ia"))it.push("Automatización con IA");
    p={ey:"Combo personalizado",name:"PLAN PERSONALIZADO",items:it};
  }
  emp.style.display="none";fill.classList.add("show");
  document.getElementById("planEy").textContent=p.ey;
  document.getElementById("planName").textContent=p.name;
  document.getElementById("planList").innerHTML=p.items.map(i=>`<li><div class="plan-chk">✓</div><span>${i}</span></li>`).join("");
  const msg=encodeURIComponent(`Hola Dimark! Me interesa el ${p.name}. Incluye: ${p.items.join(", ")}. ¿Pueden darme una propuesta?`);
  document.getElementById("planWA").href=`https://api.whatsapp.com/send/?phone=573203920599&text=${msg}`;
  if(sel.size===1)setTimeout(()=>document.getElementById("planFill").scrollIntoView({behavior:"smooth",block:"nearest"}),150);
}
function wppLink(num){
  const clean=num.replace(/\D/g,"");
  return `https://api.whatsapp.com/send/?phone=${clean}&text=${encodeURIComponent("Hola! Me interesa conocer más sobre el asistente AVI.")}`;
}
function renderCasos(cat){
  const el=document.getElementById("casosContent");
  if(cat==="web"){
    el.innerHTML=`<div class="web-scroll-grid">${CASOS.web.map(c=>`
      <div class="web-scroll-card">
        <div class="web-scroll-window">
          <img class="web-scroll-img" src="${c.img}" alt="${c.name}" loading="lazy">
        </div>
        <div class="web-scroll-footer">
          <span class="web-scroll-name">${c.name}</span>
          <a class="web-scroll-btn" href="${c.link}" target="_blank">Visitar →</a>
        </div>
      </div>`).join("")}</div>`;
  }else if(cat==="seo"){
    el.innerHTML=`<div class="seo-grid">${CASOS.seo.map(c=>`
      <div class="seo-card">
        <div class="seo-rank">🏆 Posición #1 en Google</div>
        <div class="seo-kw">${c.kw}</div>
        <div class="seo-domain">${c.domain}</div>
        <a class="seo-btn" href="${c.link}" target="_blank">Comprobar en Google →</a>
      </div>`).join("")}</div>`;
  }else if(cat==="google-ads"){
    el.innerHTML=`<div class="ads-img-grid">${CASOS.googleAds.map(img=>`
      <div class="ads-img-card">
        <img src="${img}" alt="Caso Google Ads" loading="lazy">
      </div>`).join("")}</div>`;
  }else if(cat==="meta-ads"){
    el.innerHTML=`<div class="ads-img-grid">${CASOS.metaAds.map(img=>`
      <div class="ads-img-card">
        <img src="${img}" alt="Caso Meta Ads" loading="lazy">
      </div>`).join("")}</div>`;
  }else if(cat==="avi"){
    el.innerHTML=`<div class="avi-img-grid">${CASOS.avi.map(c=>`
      <div class="avi-img-card">
        <div class="avi-img-logo">
          <img src="${c.img}" alt="Cliente AVI" loading="lazy">
        </div>
        <div class="avi-img-footer">
          <a class="avi-wpp-btn" href="${wppLink(c.wpp)}" target="_blank">💬 Probar AVI</a>
        </div>
      </div>`).join("")}</div>`;
  }
}
document.querySelectorAll(".ctab").forEach(t=>{
  t.addEventListener("click",()=>{document.querySelectorAll(".ctab").forEach(x=>x.classList.remove("on"));t.classList.add("on");renderCasos(t.dataset.cat);});
});
window.addEventListener("scroll",()=>document.getElementById("nav").classList.toggle("scrolled",window.scrollY>50));

// LIGHTBOX (casos Google Ads / Meta Ads)
const lb=document.getElementById("lightbox"),lbImg=document.getElementById("lightboxImg");
function openLightbox(src){lbImg.src=src;lb.classList.add("show");document.body.style.overflow="hidden";}
function closeLightbox(){lb.classList.remove("show");lbImg.src="";document.body.style.overflow="";}
document.getElementById("casosContent").addEventListener("click",e=>{
  const card=e.target.closest(".ads-img-card");
  if(card){const im=card.querySelector("img");if(im)openLightbox(im.src);}
});
lb.addEventListener("click",e=>{if(e.target!==lbImg)closeLightbox();});
document.getElementById("lightboxClose").addEventListener("click",closeLightbox);
document.addEventListener("keydown",e=>{if(e.key==="Escape")closeLightbox();});

renderCasos("web");
</script>



<?php else : ?>



    <?php if (get_query_var('pagename') == "blog") : ?>

    <?php else : ?>
        <?php if (have_posts()) : while (have_posts()) : the_post(); ?>
                <?= the_content() ?>
        <?php endwhile;
        endif; ?>

    <?php endif; ?>

    <!-- <?php if (is_category()) : ?>
                <?php include 'category_list.php'; ?>
            <?php endif; ?> -->

<?php endif; ?>

<?php get_footer(); ?>


<?php wp_footer(); ?>