/*
Theme Name: Dimark
Theme URI: https://dimark.co/
Author: Dimark Group
Author URI: https://dimark.co/
Description: Dimark es un tema totalmente SEO optimizado para garantizar un alto rendimiento en los motores de búsqueda y cumplir las métricas de Core Web Vitals las cuales son esenciales para posicionar un sitio web en Google de manera orgánica.
Version: 1.0
License: GNU General Public License v2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Text Domain: Dimark.co
Tags: seo, elementor, core web vitals, google, organico
*/


