<?php
/**
 * Template páginas estáticas — usa the_content() para SEO con Yoast.
 */
get_header(); ?>
<main class="wrap" style="padding:130px 24px 80px;min-height:60vh;">
    <?php while (have_posts()) : the_post(); ?>
        <article class="editable-content" style="max-width:780px;">
            <h1><?php the_title(); ?></h1><div style="font-size:.85rem;color:#666;margin-bottom:24px;"><?php echo esc_html(get_the_date()); ?></div>
            <?php the_content(); ?>
        </article>
    <?php endwhile; ?>
</main>
<?php get_footer();
