/*
Theme Name: DIMARK
Theme URI: https://supercerebro.com
Author: SuperCerebro by DIMARK
Author URI: https://supercerebro.com
Description: Tema generado por SuperCerebro para DIMARK. Industria: MARKETING DIGITAL, SOFTWARE, INTELIGENCIA ARTIFICIAL.
Version: 1.0.0
Requires at least: 5.0
Tested up to: 6.4
Requires PHP: 7.0
License: GNU General Public License v2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Text Domain: dimark
*/

*,*::before,*::after{box-sizing:border-box;margin:0;padding:0}
:root{
  --red:#B50D0D;--red2:#931818;--red3:#c01515;
  --black:#181818;--black2:#0d0d0d;
  --dark:#1f1f1f;--dark2:#252525;--dark3:#2c2c2c;
  --gray:#8A8A8A;--gray2:#3F3F3F;
  --white:#ffffff;
  --border:rgba(255,255,255,0.07);
  --border2:rgba(255,255,255,0.13);
  --r:6px;--rl:12px;
  --gutter:max(52px, calc((100% - 1400px) / 2));
}
@media(max-width:960px){:root{--gutter:20px}}
html{scroll-behavior:smooth}
body{font-family:'Work Sans',sans-serif;background:var(--black);color:var(--white);overflow-x:hidden}
a{text-decoration:none;color:inherit}
img{display:block;max-width:100%}
::-webkit-scrollbar{width:3px}
::-webkit-scrollbar-thumb{background:var(--red)}

/* NAV */
.nav{position:fixed;top:0;left:0;right:0;z-index:999;height:70px;display:flex;align-items:center;justify-content:space-between;padding:0 var(--gutter);background:rgba(24,24,24,0.97);backdrop-filter:blur(20px);border-bottom:1px solid var(--border);transition:box-shadow .3s}
.nav.scrolled{box-shadow:0 4px 40px rgba(0,0,0,.8)}
.nav-logo img{height:32px;width:auto}
.nav-links{display:flex;align-items:center;gap:32px;font-size:13px;font-weight:600;color:var(--gray);text-transform:uppercase;letter-spacing:.8px}
.nav-links a{transition:color .2s}
.nav-links a:hover{color:var(--white)}
.nav-btn{background:var(--red);color:#fff;padding:11px 26px;border-radius:var(--r);font-family:'Work Sans',sans-serif;font-size:13px;font-weight:700;text-transform:uppercase;letter-spacing:.8px;border:none;cursor:pointer;transition:background .2s,transform .1s;display:inline-block;white-space:nowrap}
.nav-btn:hover{background:var(--red2);transform:translateY(-1px)}

/* HERO */
.hero{min-height:100vh;background:var(--black2);display:flex;flex-direction:column;justify-content:center;padding:130px var(--gutter) 90px;position:relative;overflow:hidden}
.hero::before{content:'';position:absolute;inset:0;background-image:linear-gradient(rgba(255,255,255,.016) 1px,transparent 1px),linear-gradient(90deg,rgba(255,255,255,.016) 1px,transparent 1px);background-size:72px 72px;pointer-events:none}
.hero::after{content:'';position:absolute;bottom:0;left:0;right:0;height:1px;background:linear-gradient(90deg,transparent,var(--red),transparent)}
.hero-glow{position:absolute;top:0;right:0;bottom:0;width:45%;background:radial-gradient(ellipse at 80% 50%,rgba(181,13,13,0.08) 0%,transparent 65%);pointer-events:none}
.hero-vline{position:absolute;top:12%;right:9%;bottom:12%;width:1px;background:linear-gradient(to bottom,transparent,rgba(181,13,13,.25),transparent)}
.hero-logobg{position:absolute;right:3%;top:50%;transform:translateY(-50%);opacity:.28;pointer-events:none;width:min(620px,46vw);filter:drop-shadow(0 0 50px rgba(181,13,13,.45))}

.hero-tag{display:inline-flex;align-items:center;gap:12px;font-size:11px;font-weight:700;letter-spacing:3px;text-transform:uppercase;color:var(--red);margin-bottom:28px}
.hero-tag-line{width:36px;height:2px;background:var(--red)}

.hero h1{font-weight:900;font-size:clamp(50px,7.8vw,100px);line-height:.9;letter-spacing:-2px;text-transform:uppercase;margin-bottom:32px;max-width:860px;position:relative;z-index:1}
.h1-red{color:var(--red);display:block}
.h1-ghost{display:block;color:var(--white)}

.hero-desc{font-size:17px;font-weight:300;color:var(--gray);line-height:1.8;max-width:560px;margin-bottom:44px;position:relative;z-index:1}
.hero-desc b{color:var(--white);font-weight:600}

.hero-btns{display:flex;gap:14px;flex-wrap:wrap;position:relative;z-index:1;margin-bottom:80px}
.btn-red{background:var(--red);color:#fff;padding:15px 36px;border-radius:var(--r);font-family:'Work Sans',sans-serif;font-size:13px;font-weight:700;text-transform:uppercase;letter-spacing:1px;border:none;cursor:pointer;display:inline-block;transition:background .2s,transform .15s,box-shadow .2s}
.btn-red:hover{background:var(--red2);transform:translateY(-2px);box-shadow:0 10px 32px rgba(181,13,13,.5)}
.btn-ghost{background:transparent;color:#fff;padding:15px 36px;border-radius:var(--r);font-family:'Work Sans',sans-serif;font-size:13px;font-weight:700;text-transform:uppercase;letter-spacing:1px;border:1.5px solid rgba(255,255,255,.18);cursor:pointer;display:inline-block;transition:all .2s}
.btn-ghost:hover{border-color:#fff;background:rgba(255,255,255,.05);transform:translateY(-2px)}

.hero-scroll{position:absolute;bottom:34px;left:var(--gutter);display:flex;align-items:center;gap:12px;font-size:11px;font-weight:600;letter-spacing:2.5px;text-transform:uppercase;color:var(--gray2)}
.hero-scroll-line{width:52px;height:1px;background:var(--gray2)}

/* STATS */
.stats{display:grid;grid-template-columns:repeat(5,1fr);background:var(--dark);border-bottom:1px solid var(--border);padding:0 var(--gutter)}
.stat{padding:34px 22px;text-align:center;border-right:1px solid var(--border);position:relative;overflow:hidden;transition:background .2s;cursor:default}
.stat::after{content:'';position:absolute;bottom:0;left:0;right:0;height:0;background:var(--red);transition:height .25s}
.stat:hover::after{height:3px}
.stat:last-child{border-right:none}
.stat:hover{background:var(--dark2)}
.stat-n{font-weight:900;font-size:44px;line-height:1;color:var(--white);margin-bottom:7px}
.stat-n .acc{color:var(--red)}
.stat-l{font-size:12px;font-weight:500;color:var(--gray);line-height:1.45;text-transform:uppercase;letter-spacing:.5px}

/* PARTNERS */
.partners{background:var(--dark);padding:22px var(--gutter);border-bottom:1px solid var(--border);display:flex;align-items:center;gap:40px;flex-wrap:wrap}
.partners-lbl{font-size:10px;font-weight:700;letter-spacing:2.5px;text-transform:uppercase;color:var(--gray2);white-space:nowrap}
.partners-sep{width:1px;height:30px;background:var(--border2)}
.partner-row{display:flex;gap:12px;flex-wrap:wrap}
.partner{display:flex;align-items:center;gap:10px;background:var(--dark2);border:1px solid var(--border2);border-radius:var(--r);padding:10px 20px;font-size:13px;font-weight:700;transition:border-color .2s}
.partner:hover{border-color:rgba(255,255,255,.28)}
.p-dot{width:10px;height:10px;border-radius:50%;flex-shrink:0}
.p-cert{font-size:10px;font-weight:400;color:var(--gray);border-left:1px solid var(--border2);padding-left:10px;margin-left:4px}
.partner-badges{display:flex;align-items:center;gap:20px;margin-left:auto;flex-wrap:wrap}
.g-badge{height:78px;opacity:.9;transition:opacity .2s}
.g-badge:hover{opacity:1}
.m-badge{height:78px;width:auto;border-radius:10px;object-fit:contain;background:#fff;padding:8px;opacity:.9;transition:opacity .2s}
.m-badge:hover{opacity:1}

/* AVI STRIP */
.avi-strip{background:linear-gradient(135deg,#170000 0%,var(--dark2) 100%);border-left:4px solid var(--red);border-bottom:1px solid var(--border);padding:20px var(--gutter);display:flex;align-items:center;gap:20px;flex-wrap:wrap}
.avi-badge{background:var(--red);color:#fff;padding:5px 12px;border-radius:4px;font-size:10px;font-weight:800;letter-spacing:2px;text-transform:uppercase;white-space:nowrap;flex-shrink:0}
.avi-info{flex:1;min-width:200px}
.avi-title{font-size:17px;font-weight:800;color:var(--white);margin-bottom:3px}
.avi-sub{font-size:13px;font-weight:300;color:var(--gray)}
.avi-btn{background:rgba(181,13,13,.15);color:var(--red);border:1px solid rgba(181,13,13,.35);padding:10px 22px;border-radius:var(--r);font-size:12px;font-weight:700;text-transform:uppercase;letter-spacing:.8px;cursor:pointer;white-space:nowrap;transition:all .2s;display:inline-block}
.avi-btn:hover{background:var(--red);color:#fff}

/* SECTION */
.sec{padding:88px var(--gutter);border-bottom:1px solid var(--border)}
.sec-bg1{background:var(--black2)}
.sec-bg2{background:var(--dark)}

.eyebrow{display:flex;align-items:center;gap:10px;font-size:10px;font-weight:800;letter-spacing:3.5px;text-transform:uppercase;color:var(--red);margin-bottom:16px}
.eyebrow-line{width:26px;height:2px;background:var(--red);flex-shrink:0}
.sec-title{font-weight:900;font-size:clamp(30px,4.8vw,56px);line-height:.98;letter-spacing:-1.5px;text-transform:uppercase;color:var(--white);margin-bottom:12px}
.sec-sub{font-size:15px;font-weight:300;color:var(--gray);line-height:1.8;max-width:590px}

/* SERVICIOS */
.svc-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(215px,1fr));gap:2px;margin-top:52px}
.svc-card{background:var(--dark);border:1px solid var(--border);border-radius:4px;padding:30px 24px;cursor:pointer;position:relative;overflow:hidden;transition:background .2s,transform .2s,box-shadow .2s}
.svc-card::after{content:'';position:absolute;bottom:0;left:0;right:0;height:3px;background:var(--red);transform:scaleX(0);transform-origin:left;transition:transform .3s}
.svc-card:hover::after{transform:scaleX(1)}
.svc-card:hover{background:var(--dark2);transform:translateY(-3px);box-shadow:0 16px 48px rgba(0,0,0,.55)}
.svc-card.on{background:var(--red);border-color:var(--red);transform:translateY(-3px);box-shadow:0 16px 48px rgba(181,13,13,.35)}
.svc-card.on::after{display:none}
.svc-chk{position:absolute;top:13px;right:13px;width:22px;height:22px;background:rgba(255,255,255,.25);border-radius:50%;display:none;align-items:center;justify-content:center;font-size:12px;font-weight:800;color:#fff}
.svc-card.on .svc-chk{display:flex}
.svc-ico{font-size:28px;margin-bottom:16px;display:block;line-height:1}
.svc-name{font-weight:800;font-size:15px;text-transform:uppercase;letter-spacing:.8px;color:var(--white);margin-bottom:8px}
.svc-desc{font-size:12px;font-weight:400;color:var(--gray);line-height:1.65}
.svc-card.on .svc-desc{color:rgba(255,255,255,.75)}
.svc-pill{display:inline-block;margin-top:13px;background:rgba(255,255,255,.07);color:var(--gray);font-size:10px;font-weight:700;letter-spacing:1.5px;text-transform:uppercase;padding:4px 10px;border-radius:4px}
.svc-card.on .svc-pill{background:rgba(255,255,255,.2);color:#fff}

/* PLAN BOX */
.plan-box{border:1px solid var(--border);border-radius:var(--rl);overflow:hidden}
.plan-empty{background:var(--dark2);padding:66px 32px;text-align:center}
.plan-empty-ico{font-size:44px;margin-bottom:14px;display:block}
.plan-empty-t{font-weight:800;font-size:19px;text-transform:uppercase;letter-spacing:.5px;color:var(--white);margin-bottom:7px}
.plan-empty-s{font-size:14px;font-weight:300;color:var(--gray)}
.plan-fill{display:none}
.plan-fill.show{display:flex;flex-direction:column}
.plan-l{padding:46px;background:var(--dark);border-right:1px solid var(--border)}
.plan-ey{font-size:10px;font-weight:800;letter-spacing:3px;text-transform:uppercase;color:var(--red);margin-bottom:10px;display:flex;align-items:center;gap:8px}
.plan-name{font-weight:900;font-size:38px;text-transform:uppercase;letter-spacing:-.5px;color:var(--white);margin-bottom:28px;line-height:1.02}
.plan-inc-lbl{font-size:10px;font-weight:700;letter-spacing:2px;text-transform:uppercase;color:var(--gray2);margin-bottom:13px}
.plan-list{list-style:none}
.plan-list li{display:flex;align-items:flex-start;gap:12px;padding:13px 0;border-bottom:1px solid var(--border);font-size:14px;font-weight:400;color:rgba(255,255,255,.82)}
.plan-list li:last-child{border-bottom:none}
.plan-chk{flex-shrink:0;width:20px;height:20px;background:rgba(181,13,13,.2);border-radius:50%;display:flex;align-items:center;justify-content:center;color:var(--red);font-size:10px;font-weight:800;margin-top:2px}
.plan-r{padding:46px;background:var(--dark2);display:flex;flex-direction:column}
.plan-r-t{font-weight:800;font-size:18px;text-transform:uppercase;letter-spacing:.5px;color:var(--white);margin-bottom:9px}
.plan-r-s{font-size:13px;font-weight:300;color:var(--gray);line-height:1.7;margin-bottom:28px}
.btn-wa{width:100%;background:#25D366;color:#fff;border:none;padding:15px 20px;border-radius:var(--r);font-family:'Work Sans',sans-serif;font-size:14px;font-weight:800;text-transform:uppercase;letter-spacing:.8px;cursor:pointer;display:flex;align-items:center;justify-content:center;gap:10px;transition:background .2s,box-shadow .2s;margin-bottom:12px;text-decoration:none}
.btn-wa:hover{background:#1fba58;box-shadow:0 6px 24px rgba(37,211,102,.3)}
.btn-call{width:100%;background:rgba(255,255,255,.06);color:var(--white);border:1px solid var(--border2);padding:13px 20px;border-radius:var(--r);font-family:'Work Sans',sans-serif;font-size:13px;font-weight:700;text-transform:uppercase;letter-spacing:.8px;cursor:pointer;transition:background .2s;display:flex;align-items:center;justify-content:center;text-decoration:none}
.btn-call:hover{background:rgba(255,255,255,.1)}
.plan-trust{margin-top:auto;padding-top:26px;display:flex;flex-wrap:wrap;gap:12px}
.trust-it{display:flex;align-items:center;gap:6px;font-size:11px;font-weight:500;color:var(--gray2)}

/* CASOS */
.ctabs{display:flex;gap:4px;margin-bottom:36px;flex-wrap:wrap}
.ctab{padding:10px 22px;border-radius:var(--r);border:1px solid var(--border);font-size:12px;font-weight:700;text-transform:uppercase;letter-spacing:.8px;cursor:pointer;background:transparent;color:var(--gray);transition:all .2s}
.ctab:hover{border-color:var(--border2);color:var(--white)}
.ctab.on{background:var(--red);color:#fff;border-color:var(--red)}

.web-scroll-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(220px,1fr));gap:18px}
.web-scroll-card{background:var(--dark2);border:1px solid var(--border);border-radius:var(--rl);overflow:hidden;transition:transform .2s,border-color .2s,box-shadow .2s}
.web-scroll-card:hover{transform:translateY(-4px);border-color:rgba(181,13,13,.4);box-shadow:0 14px 44px rgba(0,0,0,.55)}
.web-scroll-window{height:220px;overflow:hidden;position:relative;cursor:pointer}
.web-scroll-img{width:100%;display:block;transition:transform 8s ease;transform:translateY(0)}
.web-scroll-window:hover .web-scroll-img{transform:translateY(calc(-100% + 220px))}
.web-scroll-footer{padding:14px 16px;display:flex;align-items:center;justify-content:space-between;border-top:1px solid var(--border)}
.web-scroll-name{font-size:12px;font-weight:700;color:var(--white);white-space:nowrap;overflow:hidden;text-overflow:ellipsis;max-width:130px}
.web-scroll-btn{background:var(--red);color:#fff;padding:6px 14px;border-radius:4px;font-size:10px;font-weight:800;text-transform:uppercase;letter-spacing:.8px;white-space:nowrap;flex-shrink:0;transition:background .2s;display:inline-block;text-decoration:none}
.web-scroll-btn:hover{background:var(--red2)}

.seo-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(260px,1fr));gap:16px}
.seo-card{background:var(--dark2);border:1px solid var(--border);border-radius:var(--rl);padding:26px;transition:border-color .2s,transform .2s}
.seo-card:hover{border-color:rgba(181,13,13,.4);transform:translateY(-3px)}
.seo-rank{font-size:11px;font-weight:800;letter-spacing:2px;text-transform:uppercase;color:var(--red);margin-bottom:8px}
.seo-kw{font-weight:900;font-size:20px;color:var(--white);margin-bottom:4px}
.seo-domain{font-size:12px;font-weight:400;color:var(--gray);margin-bottom:18px}
.seo-btn{display:inline-block;background:rgba(66,133,244,.15);color:#6aa3f8;border:1px solid rgba(66,133,244,.25);padding:8px 18px;border-radius:4px;font-size:11px;font-weight:700;text-transform:uppercase;letter-spacing:.8px;transition:background .2s;text-decoration:none}
.seo-btn:hover{background:rgba(66,133,244,.3)}

.ads-img-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(220px,1fr));gap:16px}
.ads-img-card{background:var(--dark2);border:1px solid var(--border);border-radius:var(--rl);overflow:hidden;transition:transform .2s,border-color .2s,box-shadow .2s}
.ads-img-card:hover{transform:translateY(-4px);border-color:rgba(181,13,13,.4);box-shadow:0 14px 44px rgba(0,0,0,.55)}
.ads-img-card img{width:100%;height:auto;display:block;cursor:zoom-in}

.lightbox{position:fixed;inset:0;z-index:2000;background:rgba(0,0,0,.92);display:none;align-items:center;justify-content:center;padding:40px;cursor:zoom-out;backdrop-filter:blur(4px)}
.lightbox.show{display:flex}
.lightbox img{max-width:100%;max-height:100%;width:auto;height:auto;border-radius:8px;box-shadow:0 24px 90px rgba(0,0,0,.75);cursor:default}
.lightbox-close{position:absolute;top:20px;right:30px;font-size:44px;line-height:1;color:#fff;cursor:pointer;font-weight:300;transition:color .2s}
.lightbox-close:hover{color:var(--red)}

.avi-img-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(200px,1fr));gap:16px}
.avi-img-card{background:var(--dark2);border:1px solid var(--border);border-radius:var(--rl);overflow:hidden;transition:transform .2s,border-color .2s,box-shadow .2s;display:flex;flex-direction:column}
.avi-img-card:hover{transform:translateY(-4px);border-color:rgba(181,13,13,.4);box-shadow:0 14px 44px rgba(0,0,0,.55)}
.avi-img-logo{height:120px;display:flex;align-items:center;justify-content:center;overflow:hidden;background:#fff;padding:16px}
.avi-img-logo img{max-height:90px;max-width:100%;object-fit:contain;display:block}
.avi-img-footer{padding:14px 16px;text-align:center;border-top:1px solid var(--border)}
.avi-wpp-btn{display:inline-block;background:#25D366;color:#fff;padding:8px 18px;border-radius:4px;font-size:11px;font-weight:800;text-transform:uppercase;letter-spacing:.8px;transition:background .2s;text-decoration:none}
.avi-wpp-btn:hover{background:#1fba58}

.certified-sec{position:relative;padding:72px var(--gutter);background:var(--dark);border-bottom:1px solid var(--border);overflow:hidden}
.certified-grid{position:relative;z-index:1;display:grid;grid-template-columns:1fr auto;gap:52px;align-items:center}
.certified-inner{max-width:860px}
.certified-badges{display:flex;align-items:center;gap:28px;flex-wrap:wrap;margin-top:28px}
.certified-badges img{height:112px;width:auto}
.certified-world{width:min(360px,30vw);height:auto;filter:drop-shadow(0 0 45px rgba(181,13,13,.4));animation:world-float 6s ease-in-out infinite}
@media(max-width:960px){.certified-grid{grid-template-columns:1fr;justify-items:center;text-align:center}.certified-world{width:240px}.certified-badges{justify-content:center}}

.ind-sec{padding:72px var(--gutter);background:var(--black2);border-bottom:1px solid var(--border)}
.ind-grid{display:grid;grid-template-columns:repeat(auto-fill,minmax(300px,1fr));gap:16px;margin-top:40px}
.ind-card{background:var(--dark);border:1px solid var(--border2);border-radius:var(--rl);padding:34px;transition:border-color .2s,transform .2s}
.ind-card:hover{border-color:rgba(181,13,13,.4);transform:translateY(-3px)}
.ind-ico{font-size:36px;margin-bottom:16px;display:block}
.ind-name{font-weight:900;font-size:22px;text-transform:uppercase;letter-spacing:-.3px;color:var(--white);margin-bottom:10px}
.ind-desc{font-size:13px;font-weight:300;color:var(--white);line-height:1.75;margin-bottom:20px}
.ind-pill{display:inline-block;background:rgba(181,13,13,.12);color:var(--red);border:1px solid rgba(181,13,13,.25);font-size:10px;font-weight:700;letter-spacing:1.5px;text-transform:uppercase;padding:5px 12px;border-radius:4px}

.ind-layout{display:grid;grid-template-columns:1fr 360px;gap:32px;align-items:start;margin-top:40px}
.ind-layout .ind-grid{margin-top:0;grid-template-columns:1fr}
.tech-panel{background:var(--dark);border:1px solid var(--border2);border-radius:var(--rl);padding:30px;position:sticky;top:90px}
.tech-title{font-size:11px;font-weight:800;letter-spacing:2px;text-transform:uppercase;color:var(--red);margin-bottom:22px;display:flex;align-items:center;gap:8px}
.tech-title::before{content:"";width:22px;height:2px;background:var(--red);flex-shrink:0}
.tech-grid{display:grid;grid-template-columns:repeat(2,1fr);gap:10px}
.tech-chip{display:flex;align-items:center;gap:10px;background:var(--dark2);border:1px solid var(--border);border-radius:var(--r);padding:11px 13px;transition:border-color .2s,transform .15s}
.tech-chip:hover{border-color:rgba(181,13,13,.4);transform:translateY(-2px)}
.tech-chip img{width:22px;height:22px;object-fit:contain;flex-shrink:0}
.tech-chip span{font-size:12px;font-weight:600;color:var(--white);white-space:nowrap;overflow:hidden;text-overflow:ellipsis}
.tech-chip.wide{grid-column:1/-1}
@media(max-width:1080px){.ind-layout{grid-template-columns:1fr}.tech-panel{position:static}}
@media(max-width:540px){.tech-grid{grid-template-columns:1fr}}

.world-sec{position:relative;background:var(--black2);border-bottom:1px solid var(--border);padding:96px var(--gutter);overflow:hidden}
.world-glow{position:absolute;top:50%;right:-6%;transform:translateY(-50%);width:62%;height:130%;background:radial-gradient(ellipse at center,rgba(181,13,13,.16) 0%,transparent 62%);pointer-events:none}
.world-inner{position:relative;z-index:1;display:grid;grid-template-columns:1fr 1.1fr;gap:52px;align-items:center}
.world-text{max-width:480px}
.world-text .sec-sub{margin-bottom:30px}
.world-img-wrap{display:flex;justify-content:center;align-items:center}
.world-img{width:100%;max-width:600px;height:auto;filter:drop-shadow(0 0 60px rgba(181,13,13,.4));animation:world-float 6s ease-in-out infinite}
@keyframes world-float{0%,100%{transform:translateY(0)}50%{transform:translateY(-16px)}}
@media(max-width:960px){
  .world-sec{padding:58px 20px}
  .world-inner{grid-template-columns:1fr;gap:34px;text-align:center}
  .world-text{max-width:none}
  .world-text .eyebrow{justify-content:center}
  .world-img{max-width:420px}
}

.combo-layout{display:grid;grid-template-columns:1fr 380px;gap:32px;align-items:start}
@media(max-width:1080px){.combo-layout{grid-template-columns:1fr}}
.combo-sticky{position:sticky;top:90px}

footer{background:var(--dark);border-top:1px solid var(--border);padding:66px var(--gutter) 30px}
.footer-top{display:grid;grid-template-columns:2fr 1fr 1fr 1fr;gap:52px;margin-bottom:48px}
.footer-logo-img{height:36px;margin-bottom:16px}
.footer-tag{font-size:14px;font-weight:300;color:var(--gray);line-height:1.7;max-width:260px;margin-bottom:22px}
.footer-sedes{font-size:12px;font-weight:400;color:var(--gray2);line-height:1.85;margin-bottom:22px}
.footer-sedes strong{color:var(--gray);font-weight:600}
.socials{display:flex;gap:10px}
.soc{width:38px;height:38px;border-radius:var(--r);background:var(--dark2);border:1px solid var(--border);display:flex;align-items:center;justify-content:center;font-size:16px;transition:background .2s,border-color .2s;text-decoration:none;color:var(--white)}
.soc:hover{background:var(--red);border-color:var(--red)}
.footer-col-t{font-size:10px;font-weight:800;letter-spacing:2.5px;text-transform:uppercase;color:var(--gray2);margin-bottom:18px}
.footer-col a,.footer-col p{display:block;font-size:14px;font-weight:400;color:var(--gray);margin-bottom:10px;transition:color .2s}
.footer-col a:hover{color:var(--white)}
.footer-bottom{border-top:1px solid var(--border);padding-top:24px;display:flex;justify-content:space-between;align-items:center;flex-wrap:wrap;gap:10px;font-size:12px;color:var(--gray2)}

@media(max-width:960px){
  .nav{padding:0 20px}.nav-links{display:none}
  .hero{padding:108px 20px 78px}.hero-vline{display:none}.hero h1{font-size:52px}
  .stats{grid-template-columns:repeat(3,1fr)}
  .stat:nth-child(3){border-right:none}
  .stat:nth-child(4),.stat:nth-child(5){border-top:1px solid var(--border)}
  .partners{padding:18px 20px;gap:16px}.partners-sep{display:none}
  .avi-strip{padding:18px 20px}.sec{padding:58px 20px}
  .plan-fill.show{grid-template-columns:1fr}.plan-r{border-top:1px solid var(--border)}
  .footer-top{grid-template-columns:1fr 1fr;gap:30px}footer{padding:44px 20px 24px}
}
@media(max-width:540px){
  .stats{grid-template-columns:repeat(2,1fr)}
  .stat:nth-child(3){border-right:1px solid var(--border);border-top:1px solid var(--border)}
  .stat:nth-child(4){border-top:1px solid var(--border);border-right:none}
  .stat:nth-child(5){grid-column:1/-1}
  .footer-top{grid-template-columns:1fr}
}
/* === Estilos auto-generados para content editable === */
.about-text,.editable-content{font-size:.95rem;line-height:1.8;}
.about-text h1,.about-text h2,.editable-content h1,.editable-content h2{margin:0 0 30px;line-height:1.1;}
.about-text p,.editable-content p{margin:0 0 20px;}
.about-text strong,.editable-content strong{font-weight:700;}
.about-text a,.editable-content a{text-decoration:underline;}
