<?php
/**
 * Template-part: partners
 */
?>
<div class="partners">
  <span class="partners-lbl">Partners certificados</span>
  <div class="partners-sep"></div>
  <div class="partner-row">
    <div class="partner"><span class="p-dot" style="background:#4285F4"></span>Google Ads<small class="p-cert">Partner oficial</small></div>
    <div class="partner"><span class="p-dot" style="background:#1877F2"></span>Meta Ads<small class="p-cert">Partner oficial</small></div>
  </div>
  <div class="partner-badges">
    <a href="https://www.google.com/partners/agency?id=2597029018" target="_blank">
      <img class="g-badge" src="https://www.gstatic.com/partners/badge/images/2025/PartnerBadgeClickable.svg" alt="Google Partner">
    </a>
    <img class="m-badge" src="https://dimark.co/wp-content/uploads/2026/01/WhatsApp-Image-2026-01-13-at-9.39.34-AM.jpeg" alt="Meta Business Partner">
  </div>
</div>
